
Include "data.geo";

Group{
    Domaine = Region[{air,boiteinf,dielec}];
    Dielectrique = Region[{dielec}];
    BoiteInf = Region[{boiteinf}];
    Masse = Region[{masse}];
    DeltaV = Region[{deltav}];
}

Function{
    eps0 = 8.854187818e-12;
    epsr = 9.8;
    eps[#{air,boiteinf}] = eps0;
    eps[#{dielec}] = eps0*epsr;
    V1 = 1;
}

Jacobian{
    { Name Jvol;
      Case {
        { Region BoiteInf ; Jacobian VolAxiSphShell{Rboite, Rboite+5}; }
        { Region All ; Jacobian VolAxi ; }
      }
    }
  }
  
  Integration {
    { Name Integ;
      Case { 
        {Type Gauss;
      Case { 
        { GeoElement Line ; NumberOfPoints 2; }
        { GeoElement Triangle ; NumberOfPoints 6; } }
        }
      }
    }
  }

  Constraint {	
    {Name TensionsImposees ;
      Case {      
        { Region Masse ; Type Assign ; Value 0. ; }
        { Region DeltaV ; Type Assign ; Value V1 ; }
      }
    }
  }

  FunctionSpace {
    { Name Hgrad ; Type Form0 ; 
      BasisFunction { 
        { Name sn ; NameOfCoef vn ; Function BF_Node ; 
            Support Region[{Domaine}]  ; Entity NodesOf[All] ; }
      } 
      Constraint {
        { NameOfCoef vn  ; EntityType NodesOf ; NameOfConstraint TensionsImposees ; }
      }
    }
  }

  Formulation {
    { Name Electrostat ; Type FemEquation ;
      Quantity {
        { Name v  ; Type Local  ; NameOfSpace Hgrad ; }
      }
     Equation {
        Galerkin { [ eps[]*Dof{Grad v}  , {Grad v} ] ;
          In Domaine ; Jacobian Jvol ; Integration Integ ; }
      }
    }
  }
  
  Resolution {
    { Name analyse ;
      System {
        { Name Sys ; NameOfFormulation Electrostat ; }
      }
      Operation {
        Generate[Sys] ; 
        Solve[Sys] ;
        SaveSolution[Sys] ;
      }
    }
  }

  PostProcessing {
    { Name PostProc ; NameOfFormulation Electrostat ;
      Quantity {	
        { Name v  ; Value { Term { [ {v} ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name e  ; Value { Term { [ -{Grad v} ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name d  ; Value { Term { [ -eps[]*{Grad v} ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name nrj ; Value { Integral { [ 2*Pi*eps[]*SquNorm[{Grad v}] ]  ; In Domaine ; 
          Jacobian Jvol ; Integration Integ ;} } } 
        { Name C ; Value { Integral { [ 4*Pi*eps[]*SquNorm[{Grad v}]/(V1^2) ]  ; In Domaine ; 
          Jacobian Jvol ; Integration Integ ;} } } 
      }
    }
  }
  
  PostOperation PostOp UsingPost PostProc {
    Print[ v, OnElementsOf Domaine, File "v.pos"] ;
    Print[ d, OnElementsOf Domaine, File "d.pos"] ;
    Print[ e, OnElementsOf Domaine, File "e.pos"] ;
    Print[ nrj[Domaine], OnGlobal, File "nrj.dat", 
      SendToServer "Modele/Resultats/1Energie (J)", Color "AliceBlue" ];
    Print[ C[Domaine], OnGlobal, File "capacité.dat", 
      SendToServer "Modele/Resultats/2Capacité (F)", Color "AliceBlue" ];  
  }