/*
 Fichier de donnees pour « coupleur.geo ».
 Julien Fontchastagner, UL-GREEN, juin 2021.
*/


// Valeurs par défaut
alpha10 =  0.9;
alpha20 =  0.6;
R10 =   3.8E-002 ;
ea10 =   5.5E-003 ;
ea20 =   4.000E-003 ;
L0 =   8.7E-002 ;
pp0 =   4.0;
sigma10 =   5.0;
sigma20 =   3.0;
entrf0 =   4.0E-003 ;
ec10 =   4.00E-003 ;
ec20 =   2.6E-003 ;


DefineConstant[  
  alpha1 = {alpha10*100, Min 60, Max 95, Step 1, 
    Name "Modèle/Paramètres coupleur/01Largeur angulaire aimants interieurs (% du pas polaire)"},
  alpha2 = {alpha20*100, Min 60, Max 95, Step 1, 
    Name "Modèle/Paramètres coupleur/02Largeur angulaire aimants exterieurs (% du pas polaire)"},
  R1 = {R10*1e3, Min 10, Max 100, Step 1, 
    Name "Modèle/Paramètres coupleur/03Rayon intérieur (en mm)"},
  ea1 = {ea10*1e3, Min 4, Max 20, Step 0.5, 
    Name "Modèle/Paramètres coupleur/04Épaisseur aimants intérieurs (en mm)"},
  ea2 = {ea20*1e3, Min 4, Max 20, Step 0.5, 
    Name "Modèle/Paramètres coupleur/05Épaisseur aimants extérieurs (en mm)"},
  entrf = {entrf0*1e3, Min 2, Max 10, Step 0.5, 
    Name "Modèle/Paramètres coupleur/06Épaisseur entrefer (en mm)"},
  ec1 = {ec10*1e3, Min 2, Max 20, Step 0.5, 
    Name "Modèle/Paramètres coupleur/07Épaisseur culasse intérieure (en mm)"},
  ec2 = {ec20*1e3, Min 2, Max 20, Step 0.5, 
    Name "Modèle/Paramètres coupleur/08Épaisseur culasse extérieure (en mm)"},
  L = {L0*1e3, Min 20, Max 150, Step 1, 
    Name "Modèle/Paramètres coupleur/09Longueur (en mm)"},  
  pp = {pp0, Min 2, Max 10, Step 1, 
    Name "Modèle/Paramètres coupleur/10Paires de pôles" },
  sigma1 = {sigma10, Choices {1="Ferrites", 2="NdFeB 1.0 T",
      3="NdFeB 1.1 T", 4="NdFeB 1.2 T", 5="NdFeB 1.3 T", 6="NdFeB 1.4 T"}, 
    Name "Modèle/Paramètres coupleur/11Type d'aimants intérieurs"}, 
  sigma2 = {sigma20, Choices {1="Ferrites", 2="NdFeB 1.0 T",
      3="NdFeB 1.1 T", 4="NdFeB 1.2 T", 5="NdFeB 1.3 T", 6="NdFeB 1.4 T"}, 
    Name "Modèle/Paramètres coupleur/12Type d'aimants extérieurs"}
]; 

alpha1 = alpha1/100;
alpha2 = alpha2/100;
R1 = R1*1e-3;
ea1 = ea1*1e-3;
ea2 = ea2*1e-3;
ec1 = ec1*1e-3;
ec2 = ec2*1e-3;
L = L*1e-3;
entrf = entrf*1e-3;

// Rayons intermediaires
R0 = R1 - ec1;
R2 = R1 + ea1;
R3 = R2 + entrf;
R4 = R3 + ea2;
R5 = R4 + ec2;

// parametres geometriques supplementaires
Ri = 0.6*R0;
Re = 1.2*R5;

// Largeur maille de reference
ndiv = 5;
lmailg = entrf/ndiv;

// parametres physiques
Br = {0.4,1.0,1.1,1.2,1.3,1.4};

braim1 = Br(sigma1-1);
muraim1 = 1.0;

braim2 = Br(sigma2-1);
muraim2 = 1.0;

murcul1 = 500;
murcul2 = 500;

DefineConstant[ 
   typgeom = {0, Choices {0="2D", 1="3D"}, 
     Name "Modèle/Paramètres modèle/1Géométrie 2D ou 3D"},
    NL = {0, Choices {0="Linéaire", 1="Non-linéaire"}, 
      Name "Modèle/Paramètres modèle/2Calcul en linéaire ou non-linéaire"}
  ];

// Numeros des regions physiques
GAUCHE = 1001;
DROITE = 1002;
DIRICHLET = 1003;

AIM1 = 2000;
AIM2N = 2001;
AIM2S = 2002;
AIR = 2003;
ENTRF = 2004;
CUL1 = 2005;
CUL2 = 2006;
