
// Parametres geometriques
//---------------------------

// noyau electroaimant
hea0 = 3e-2;
rea0 = 1e-2;

// bobine 
//dfil = 0.5e-3;
section0 = 0.52e-6;
Ns0 = 150;
kr = 0.6;

// aimant permanent
rap0 = 0.5e-2;
hap0 = 1e-2;

// distance inter-aimants
dia0 = 0.5e-2;


// Parametres physiques
//------------------------

Ibob0 = 10;
Br0 = 1.0;


// Interface graphique 
//-----------------------
DefineConstant[  
  TypFe = {1, Choices {1="Ferrite", 2="XC10", 3="M800"},
    Name "Modèle/Paramètres/01Bobine/00 Matériau noyau"},
  hea = {hea0*1e3, Min 10, Max 100, Step 1,  
    Name "Modèle/Paramètres/01Bobine/01Hauteur (en mm)"},
  rea = {rea0*1e3, Min 5, Max 50, Step 0.5,  
    Name "Modèle/Paramètres/01Bobine/02Rayon noyau ferreux (en mm)"},
  section = {section0*1e6, Choices {0.11="0,11",0.2="0,2",0.33="0,33",
      0.4="0,4",0.52="0,52",0.7="0,7",0.82="0,82",1.1="1,1",1.3="1,3",
      1.5="1,5",2.5="2,5",3.3="3,3"},  
    Name"Modèle/Paramètres/01Bobine/03Section fil (en mm^2)"},
  Ns = {Ns0, Min 10, Max 250, Step 5,  
    Name "Modèle/Paramètres/01Bobine/04Nombre de spires"},
  Ibob = {Ibob0, Min 0, Max 50, Step 0.1,  
    Name "Modèle/Paramètres/01Bobine/05Courant (en A)"},
  rap = {rap0*1e3, Min 2.5, Max 25, Step 0.1,  
    Name "Modèle/Paramètres/02Aimant/01Rayon aimant (en mm)"},
  hap = {hap0*1e3, Min 5, Max 50, Step 0.5,  
    Name "Modèle/Paramètres/02Aimant/02Hauteur aimant (en mm)"},
  Br = {Br0, Choices {0.4 = "Ferrite", 0.9="NdFeB 0,9 T", 
      1.0="NdFeB 1,0 T", 1.1="NdFeB 1,1 T", 1.2="NdFeB 1,2 T"}, 
    Name "Modèle/Paramètres/02Aimant/03Type d'aimant"},
  dia = {dia0*1e3, Min 1, Max 50, Step 0.1, 
    Name "Modèle/Paramètres/03Dispositif/04Distance aimant-bobine (en mm)"}
];


// retour en m :
hea = hea*1e-3;
rea = rea*1e-3;
section = section*1e-6;
rap = rap*1e-3;
hap = hap*1e-3;
dia = dia*1e-3;

// calculs grandeurs annexes
//-----------------------------
htot = hea+dia+hap;
epbob = Ns*section/kr/hea;
jeq = Ns*Ibob/(hea*epbob);

rdom = 1.5*Sqrt[(htot/2)^2+(rea+epbob)^2];
rext = 1.2*rdom;

// Parametres maillage
//----------------------
lc = (rap<epbob)?rap:epbob/25;
lcdom = rdom/25;
nehea = 40;
nerea = 20;
neepbob = 12;
nerap = 20;
nehap = 20;
neent = 25;

// regions physiques
//---------------------
BORD = 500;
STM = 501;
AIR = 1000;
NOY = 1001;
BOB = 1002;
AIM = 1003;
INF = 1004;
