
// resolution du probleme

Include "data.geo";

Group{
  Domaine = Region[{NOY,BOB,AIM,AIR,INF}];
  Air = Region[{AIR}];
  Fer = Region[{NOY}];
  NonMag = Region[{BOB,AIM,AIR,INF}];
  Bobine = Region[{BOB}];
  Aimant = Region[{AIM}];
  BoiteInf = Region[{INF}];
  Bord = Region[{BORD}];
  STenseur = Region[{STM}];
  Vol_Force = Region[Air, OnOneSideOf STenseur] ;
}

Include "BH.pro";

Function{
  mu0 = 4e-7*Pi;
  //mur = 500;
  //nu[#{NonMag}] = 1.0/mu0;
  //nu[#{Fer}] = 1.0/(mu0*mur);
  nu[#{NonMag}] = 1.0/mu0;
  nu[#{Fer}] = nu_1[$1];
  dhdb_NL[#{Fer}] = dhdb_1[$1];
  j[#{Bobine}] = Vector[0,0,-jeq];
  br[#{Aimant}] = Vector[0,Br,0];
  TM[] = ( SquDyadicProduct[$1] - SquNorm[$1] * TensorDiag[0.5, 0.5, 0.5] ) * nu[] ;
}

Jacobian{
  { Name Jvol;
    Case {   
      { Region BoiteInf ; Jacobian VolAxiSquSphShell{rdom, rext}; }
      { Region All ; Jacobian VolAxiSqu ; } 
    }
  }
}

Integration{
  { Name Integ;
    Case { 
      {Type Gauss;
	Case { 
	  { GeoElement Line ; NumberOfPoints 2; }
	  { GeoElement Triangle ; NumberOfPoints 6; } }
      }
    }
  }
}

Constraint {	
  { Name Dirichlet ;
    Case {      
      { Region Bord ; Type Assign ; Value 0. ; }
    }
  }
  { Name TenseurAimant ;
    Case {
      { Region STenseur ; Value 1. ; }
    }
  }
}

FunctionSpace {
  { Name Hrot ; Type Form1 ; 
    BasisFunction { 
      { Name se ; NameOfCoef ae ; Function BF_PerpendicularEdge ; 
	Support Region[{Domaine}]  ; Entity NodesOf[All] ; }
    } 
    Constraint {
      { NameOfCoef ae  ; EntityType NodesOf ; NameOfConstraint Dirichlet ; }
    }
  }
  { Name TenseurAim ; Type Form0 ;
    BasisFunction {     
      { Name sn ; NameOfCoef un ; Function BF_GroupOfNodes ; 
	Support Air ; Entity GroupsOfNodesOf[ STenseur ] ; }       
    }
    Constraint {
      { NameOfCoef un ; EntityType GroupsOfNodesOf ; NameOfConstraint TenseurAimant ; }       
    }
  }
}


Formulation {
  { Name Magnetostat ; Type FemEquation ;
    Quantity {
      { Name a  ; Type Local ; NameOfSpace Hrot ; }
      { Name un ; Type Local ; NameOfSpace TenseurAim ; } 
    }
    Equation {
      
      Galerkin { [ nu[{Curl a}]*Dof{Curl a}  , {Curl a} ] ;
	In Domaine ; Jacobian Jvol ; Integration Integ ; }
      
      Galerkin { JacNL [ dhdb_NL[{Curl a}] * Dof{Curl a} , {Curl a} ] ;         In Fer ; Jacobian Jvol ; Integration Integ ; }    

      Galerkin { [ -j[]  , {a} ] ;
	In Bobine ; Jacobian Jvol ; Integration Integ ; }

      Galerkin{ [ -nu[]*br[] , {Curl a} ] ;
        In Aimant ; Jacobian Jvol ; Integration Integ ;}
      
       Galerkin { [ 0 * Dof{un} , {un} ] ;      
	 In Air ; Jacobian Jvol ; Integration Integ ; }
    }   
  }
}


Resolution {
  { Name analyse ;
    System {
      { Name Sys ; NameOfFormulation Magnetostat ; }
    }
    Operation {
      InitSolution[Sys] ;
      GenerateJac[Sys] ; 
      SolveNL[Sys] ;
      SaveSolution[Sys] ;
    }
  }
}

  PostProcessing {
    { Name PostProc ; NameOfFormulation Magnetostat ;
      Quantity {	
	{ Name j  ; Value { Local { [ j[] ] ; In Bobine ; Jacobian Jvol ; } } }
        { Name a  ; Value { Local { [ {a} ] ; In Domaine ; Jacobian Jvol ; } } }
	{ Name az  ; Value { Local { [ Norm[{a}] ] ; In Domaine ; Jacobian Jvol ; } } }
	{ Name b  ; Value { Local { [ {Curl a} ] ; In Domaine ; Jacobian Jvol ; } } }
	{ Name normb ; Value { Local { [ Norm[{Curl a}] ] ; In Domaine ; Jacobian Jvol ; } } }
	{ Name h  ; Value {
	    Local { [ nu[{Curl a}]*{Curl a} ] ; In Domaine ; Jacobian Jvol ; }  
	    Local  { [  -nu[]*br[] ] ; In Aimant ; Jacobian Jvol ; }  
	  } 
	}
	{ Name f ; Value { Integral { [ 2*Pi*CompY[- TM[{Curl a}] * {d un}] ] ;
	      In Vol_Force ; Jacobian Jvol ; Integration Integ ; } } }
      }
    }
  }
  
  PostOperation PostOp UsingPost PostProc {
    Print[ j, OnElementsOf Bobine, File "j.pos"] ;
    Print[ a, OnElementsOf Domaine, File "a.pos"] ;
    Print[ b, OnElementsOf Domaine, File "b.pos"] ;
    Print[ normb, OnElementsOf Domaine, File "normb.pos"] ;
    Print[ h, OnElementsOf Domaine, File "h.pos"] ;
    Print[ az, OnElementsOf Domaine, File "az.pos"] ;
    Echo[ Str["v0 = PostProcessing.NbViews-1;", 
	"View[v0].IntervalsType = 1;", 
	"View[v0].NbIso = 40;", 
	"View[v0].LightLines = 0;"], 
      File "tmp.geo", LastTimeStepOnly ];
    Print[ f[Air], OnGlobal, Format Table, File > "F.dat" ,
      SendToServer "Modèle/Sorties/ Force [N]", Color "AliceBlue"  ];
  }

