
Include "data.geo";

Group {
  Domaine = Region[{DISQUE}];
  Bord = Region[{BORD}];
  Diametre = Region[{DIAMETRE}];
  Dummy = Region[{100000}];
}

Include "ellipke.pro";

Function{
  sigma[] = sigma_corps;
  mu[] = mu0;
  
  // cas uniforme
  //--------------  
  If (Typesource == 1)
    bs[] = Vector[0,0,bnorm];
  EndIf

  // fil infini
  //------------
  If (Typesource == 2)
    Is[] = 2*Pi*d*bnorm/mu0;
    bs[] = Vector[0,0,mu0*Is[]/(2*Pi)/(Rd+d-X[])];
  EndIf
  
  // 2 fils infinis
  //----------------
  If (Typesource == 3)
    Is[] = 2*Pi*d*(d+e)/e*bnorm/mu0;
    bs[] = Vector[0,0,mu0*Is[]/(2*Pi)*e/(Rd+d-X[])/(Rd+d+e-X[])];
  EndIf
    
  // Spire
  //-------
  If (Typesource == 4)
    k02 = 4*r*(d+r)/(d+2*r)^2;
    Is[] = bnorm/mu0*4*(2*r+d)/(Ellipk[k02]+(r^2-(d+r)^2)/d^2*Ellipe[k02]);
    Rloc[] = Sqrt[ (Rd+d+r-X[])^2 + Y[]^2 ];
    k2[] = 4*r*Rloc[]/(r+Rloc[])^2; 
    bs[] = Vector[0,0,mu0*Is[]/4/(r+Rloc[])*(Ellipk[k2[]]+(r^2-Rloc[]^2)/(r-Rloc[])^2*Ellipe[k2[]])];
  EndIf
  
  //DefineFunction[ bs ];
  
}

Jacobian {
  { Name JVol;
    Case {
      { Region All ; Jacobian Vol; }
    }
  }
}

Integration {
  { Name I ; Case {  
      { Type Gauss ;
	Case { 
	  { GeoElement Triangle ; NumberOfPoints 6 ; }  	  
	  { GeoElement Quadrangle ; NumberOfPoints 5 ; }  
	}
      }
    }
  }
}

Constraint {	
  {Name Dirichlet;
    Case {
      { Region Bord; Type Assign; Value 0; } 
    }
  }
}



FunctionSpace {
  { Name Hcurlp ; Type Form1P ; 
    BasisFunction {
      { Name sn ; NameOfCoef tn ; Function BF_PerpendicularEdge ; 
	Support Domaine ; Entity NodesOf[All] ; }
      { Name sn2 ; NameOfCoef tn2 ; Function BF_PerpendicularEdge_2E ; 
	Support Domaine ; Entity EdgesOf[All] ; }
    } 
    Constraint { 
      { NameOfCoef tn  ; EntityType NodesOf ; NameOfConstraint Dirichlet ; }
      { NameOfCoef tn2  ; EntityType EdgesOf ; NameOfConstraint Dirichlet ; }
    }
  }
}


Formulation {
  
  { Name Tind ; Type FemEquation ;
    Quantity {
      { Name t  ; Type Local  ; NameOfSpace Hcurlp ; }
    }
    Equation {

      Galerkin { [ Dof{d t}  , {d t} ] ;
	In Domaine; Jacobian JVol ; Integration I ; }
      
      Galerkin { [ Complex[0,1]*2*Pi*freq*sigma[]*bs[] , {t} ] ;
	In Domaine; Jacobian JVol ; Integration I ; }
      
    }
  }
}


Resolution {
  { Name T_Harmonic;
    System {
      { Name A; NameOfFormulation Tind;
	Type ComplexValue; Frequency freq;
      }
    }
    Operation {
      InitSolution[A];
      Generate[A]; 
      Solve[A]; 
      SaveSolution[A];
    }
  }  
}


PostProcessing {
  { Name PostProc_T ; NameOfFormulation Tind ;
    Quantity {	
      { Name t ; Value { Term { [  {t} ] ; In Domaine ; Jacobian  JVol; } } }
      { Name bs ; Value { Term { [  bs[] ] ; In Domaine ; Jacobian  JVol; } } }
      { Name j ; Value { Term { [  {d t} ] ; In Domaine ; Jacobian  JVol; } } }
      { Name normj ; Value { Term { [  Norm[{d t}] ] ; In Domaine ; Jacobian  JVol; } } }
      If (Typesource > 1)
	{ Name I ; Value { Term {  Type Global; [ Is[] ] ; In Dummy ; Jacobian  JVol; } } }
      EndIf
    }
  }
}

PostOperation PostOp_T UsingPost PostProc_T {
  Print[ t,  OnElementsOf Domaine, File "hind.pos"] ;
  Print[ bs,  OnElementsOf Domaine, File "bs.pos"] ;
  Print[ j,  OnElementsOf Domaine, File "j.pos"] ;
  Print[ normj,  OnElementsOf Domaine, File "normj.pos"] ;
  Print[ normj, OnLine{ { -Rd,0,0 } { Rd,0,0 } } { 200 } ,
    File  "tracenormj.dat", Format SimpleTable, 
    SendToServer "Modèle/Résultats/2Densité de courant" ] ;
//  Print[ normj, OnRegion Diametre ,
//    File  "tracenormj.dat", Format SimpleTable, 
//    SendToServer "Modèle/Résultats/2Densité de courant" ] ;
  If (Typesource > 1)
    Print[ I, OnRegion Dummy, File "Ic.dat", Format SimpleTable, 
      SendToServer "Modèle/Résultats/1Courant source (en A)" ] ;
  EndIf
}
