
Include "data.geo";

Group {
  Domaine = Region[{AIR,ENTRF,CUL1,CUL2,AIM1,AIM2N,AIM2S}];
  Aimants = Region[{AIM1,AIM2N,AIM2S}];
  Domaine_sans_aimants = Region[{AIR,ENTRF,CUL1,CUL2}];
  If ( NL < 1 )
    Domaine_Lin = Region[{AIR,ENTRF,CUL1,CUL2,AIM1,AIM2N,AIM2S}];
  Else
    Domaine_Lin = Region[{AIR,ENTRF,AIM1,AIM2N,AIM2S}];
  EndIf
  Domaine_Mag = Region[{CUL1,CUL2}];
  Aimant1 = Region[{AIM1}];
  Aimant2n = Region[{AIM2N}];
  Aimant2s = Region[{AIM2S}];
  Culasse1 = Region[{CUL1}];
  Culasse2 = Region[{CUL2}];
  Entrefer = Region[{ENTRF}];
  Air = Region[{AIR}];
  Gauche = Region[{GAUCHE}];
  Droite = Region[{DROITE}];
  Dirichlet = Region[{DIRICHLET}];
}



Function{
  If ( NL > 0 )
    DefineConstant[
      // Parametres resolution Non-lineaire
      NewtonRaphson = 1,
      Nb_max_iter = 100,
      ReltolA = 1e-6,
      AbstolA = 1e-6];  
  EndIf
  If ( typgeom < 1 )
    DefineConstant[LongCouple = -L];
  Else
    DefineConstant[LongCouple = -2];
  EndIf
  DefineConstant[mu0 = 4e-7 * Pi];
}
  
If ( NL > 0 )
  Include "BH.pro";
  Function{		
    DefineFunction[
      mu, dbdh
    ];
  }
EndIf

Function{
  mu[#{Entrefer,Air}] = mu0;
  mu[#{Aimant1}] = muraim1*mu0;
  mu[#{Aimant2n,Aimant2s}] = muraim2*mu0;
  
  If ( NL < 1 )
    mu[#{Culasse1}] = murcul1*mu0;
    mu[#{Culasse2}] = murcul2*mu0;
  Else 
    mu[#{Culasse1}] = mu_1[$1];
    mu[#{Culasse2}] = mu_1[$1];
    dbdh_NL[#{Culasse1}] = dbdh_1[$1];
    dbdh_NL[#{Culasse2}] = dbdh_1[$1];
  EndIf
  br[#{Aimant1}] = braim1*Vector[X[]/Sqrt[X[]^2+Y[]^2],Y[]/Sqrt[X[]^2+Y[]^2],0];
  br[#{Aimant2n}] = braim2*Vector[X[]/Sqrt[X[]^2+Y[]^2],Y[]/Sqrt[X[]^2+Y[]^2],0];
  br[#{Aimant2s}] = -braim2*Vector[X[]/Sqrt[X[]^2+Y[]^2],Y[]/Sqrt[X[]^2+Y[]^2],0];
}
  

Jacobian {
  { Name JVol;
    Case {
      { Region Domaine ; Jacobian Vol; }
    }
  }
}

Integration {
  { Name I ; Case {  
      { Type Gauss ;
	Case { 
	  { GeoElement Quadrangle ; NumberOfPoints  4 ; }  
	  { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
	}
      }
    }
  }
}

Constraint {	
  {Name Anticyclique;
    Case {
       { Region Gauche; Type Link; RegionRef Droite;
	Coefficient (-1) ; Function Rotate[ Vector[$X,$Y,$Z], 0, 0, -Pi/pp ] ; } 
    }
  }
}



FunctionSpace {
  { Name H_grad ; Type Form0 ; 
    BasisFunction {
      { Name sn ; NameOfCoef phin ; Function BF_Node  ;
	Support Domaine ; Entity NodesOf[ All] ; }
    }
    Constraint {
      { NameOfCoef phin  ; EntityType NodesOf ; NameOfConstraint Anticyclique ; }
    }
  }
}

Formulation {
  
  { Name MagSta_phi ; Type FemEquation ;
    Quantity {
      { Name phi  ; Type Local  ; NameOfSpace H_grad ; }
    }
    Equation {
      
      Integral { [ mu[{d phi}]*Dof{d phi}  , {d phi} ] ;
	In Domaine_Lin; Jacobian JVol ; Integration I ; }
      
      If ( NL > 0)
	If (NewtonRaphson)
	  Integral { [ mu[{d phi}]*{d phi}  , {d phi} ] ;
	    In Domaine_Mag; Jacobian JVol ; Integration I ; }
	  
	  Integral { [ dbdh_NL[{d phi}] * Dof{d phi} , {d phi} ] ;
	    In Domaine_Mag; Jacobian JVol ; Integration I ; }
	  
	  Integral {  [ -dbdh_NL[{d phi}] * {d phi} , {d phi} ] ;
	    In Domaine_Mag; Jacobian JVol ; Integration I ; }
	  
	  Else
	  Integral { [ mu[{d phi}]*Dof{d phi}  , {d phi} ] ;
	    In Domaine_Mag; Jacobian JVol ; Integration I ; }
	EndIf
      EndIf

      Integral { [  -br[] , {d phi} ] ;
	In Aimants ; Jacobian JVol ; Integration I ; }
       
    }
  }
}


Resolution {
  { Name Analyse_phi ;
    System {
      { Name A ; NameOfFormulation MagSta_phi ; }
    }
    Operation {
      InitSolution[A] ;
      Generate[A] ; 
      If ( NL < 1 )
	Solve[A] ;
      Else
        Generate[A]; 
	GetResidual[A, $res0];         
	Evaluate[ $res = $res0, $iter = 0 ];         
	Print[{$iter, $res, $res / $res0},   
	  Format "Residual %03g: abs %14.12e rel %14.12e"];         
	While[$res > AbstolA && $res / $res0 > ReltolA &&  
	  $res / $res0 <= 1 && $iter < Nb_max_iter]
	{      
	  Solve[A]; 
	  Generate[A]; 
	  GetResidual[A, $res];           
	  Evaluate[ $iter = $iter + 1 ];           
	  Print[{$iter, $res, $res / $res0}, 
	    Format "Residual %03g: abs %14.12e rel %14.12e"];         
	}
      EndIf
      SaveSolution[A] ;
    }
  }
}

PostProcessing {
  { Name Champs ; NameOfFormulation MagSta_phi ;
    Quantity {	
      { Name phi ; Value { Term { [  {phi} ] 	; In Domaine ; Jacobian  JVol; } } }
      { Name b ; Value {
	  Term { [ -mu[{d phi}]*{d phi} ]; In Domaine ; Jacobian  JVol; }  
	  Term { [  br[] ]; In Aimants ; Jacobian  JVol; } 
	} 
      }
      { Name couple ; Value {
	  Integral { [ 2.0*pp*mu0*(CompX[-{d phi}]*CompY[-{d phi}]*(X[]^2-Y[]^2)
		+ (CompY[{d phi}]^2 - CompX[{d phi}]^2)*X[]*Y[])/entrf/Norm[Vector[X[],Y[],0]]*LongCouple ]; 
	    In Entrefer ; Jacobian JVol ; Integration I; }  }   
      }
    }
  }
}


PostOperation {   
  { Name Champs ; NameOfPostProcessing Champs ;     
    Operation {       
      Print[ phi, OnElementsOf Domaine, File "phi.pos" ] ;
      Print[ b, OnElementsOf Domaine, File "b.pos" ] ;
      Print[ couple[Entrefer], OnGlobal, Format SimpleTable, File "gamma.dat", 
	SendToServer "Modèle/Résultat/Couple [N.m]", Color "AliceBlue" ];
    }
  }
}

