Include "data_aimant_fer_de_cheval.geo";
Group {
  
  Aimant = Region[{AimantS,AimantN}];
  Barreau = Region[{BARREAU}];
  Air = Region[{AIR}];
  
  Dirichlet = Region[{OuterSurface}];
  Nord = Region[{NORD}];
  Sud = Region[{SUD}];
  //Vol_mu = Region[ {Air, Aimant, Barreau}];
  
  Sur_Dirichlet = Region[ OuterSurface ];
  

  
  Domaine = Region[ {Air, AimantS,AimantN,BARREAU} ];
  
  Bords = Region[{BORDSBARREAU}];
  Couche_Elts = Region[Air, OnOneSideOf Bords] ;
  
}


Function{
  mu[#{Air}] = mu0;
  mu[#{AimantS,AimantN}] = mu0;
  mu[#{Barreau}] = mur*mu0;
  
  // Tenseur : forme en b permettant de calculer la force le dollar permet de définir la variable en argument de la fonction
  TM[] = ( SquDyadicProduct[$1] - SquNorm[$1] * TensorDiag[0.5, 0.5, 0.5] ) / mu[] ;

}

Jacobian {
  { Name JVol;
    Case {
      { Region Domaine  ; Jacobian Vol; }
    }
  }
}

Integration {
  { Name Int ;
    Case {  { Type Gauss ;
	Case { 
	  { GeoElement Triangle ; NumberOfPoints  4 ; }  
	  { GeoElement Quadrangle ; NumberOfPoints  4 ; }  
	  { GeoElement Tetrahedron  ; NumberOfPoints  5 ;}
	  { GeoElement Hexahedron  ; NumberOfPoints  6 ;}
	  { GeoElement Prism ; NumberOfPoints 6 ; }
	}
      }
    }
  }
}
Constraint {
  
  { Name phi ; 
    Case {
      { Region Sur_Dirichlet ; Value 0. ; }
    }
  }
  
  { Name phir_impose ; //contrainte sur la face parallele au barreau
    Case {
      { Region Nord ; Value 1. ; }
      { Region Sud ; Value 0. ; }
    }
  }
  
  { Name Dirichlet ; //Surface exterieure, frontière de l'ensemble
    Case {
      { Region Sur_Dirichlet ; Value 0. ; }
    }
  }

  { Name Bords_barreau ; //Surface exterieure du barreau, pour calcul de la force
    Case {
      { Region Bords ; Value 1. ; }
    }
  }
  
}




FunctionSpace {
  
  // espace pour calculer le champ permettant d'avoir la direction de Br
  { Name Hgrad_aimant ; Type Form0 ;
    BasisFunction {
      { Name srn ; NameOfCoef phirn ; Function BF_Node  ;
	Support Aimant ; Entity NodesOf[ All] ; }
    }
    Constraint {
      { NameOfCoef phirn ; EntityType NodesOf ; NameOfConstraint phir_impose ; }
    }
  }
  
  // potentiel scalaire magnetique
  { Name Hgrad ; Type Form0 ;
    BasisFunction {
      { Name sn ; NameOfCoef phin ; Function BF_Node  ;
	Support Domaine ; Entity NodesOf[ All] ; }
    }
    Constraint {
      { NameOfCoef phin ; EntityType NodesOf ; NameOfConstraint Dirichlet ; }
    }
  }

  // pour le tenseur de Maxwell (sur la couche d'éléments "collés" au barreau)
  { Name HBords ; Type Form0 ;
    BasisFunction {
      { Name sn ; NameOfCoef un ; Function BF_GroupOfNodes ;
	Support Air ; Entity GroupsOfNodesOf[ Bords ] ; }
    }
    Constraint {
      { NameOfCoef un ; EntityType GroupsOfNodesOf ; NameOfConstraint Bords_barreau ; }
    }
  }


}

Formulation {  
  // champ permettant d'avoir la direction de br par son grad
  { Name donne_dir_br; Type FemEquation ;
    Quantity {
      { Name phir  ; Type Local  ; NameOfSpace Hgrad_aimant ; }
    }
    Equation {
      Galerkin { [ Dof{d phir} , {d phir} ] ;// d=grad et dof=div
	In Aimant ; Jacobian JVol ; Integration Int ; }
    }
  }
  
  { Name MagSta_phi; Type FemEquation ;
    Quantity {
      { Name phir  ; Type Local  ; NameOfSpace Hgrad_aimant ; }
      { Name phi  ; Type Local  ; NameOfSpace Hgrad ; }
      { Name un ; Type Local ; NameOfSpace HBords ; }
    }
    Equation {
      Galerkin { [ mu[] * Dof{d phi} , {d phi} ] ;
	In Domaine ; Jacobian JVol ; Integration Int ; }
      
      Galerkin { [ -braimant/Norm[{d phir}]*{d phir} , {d phi} ] ;
	In Aimant ; Jacobian JVol ; Integration Int ; }
      
      // terme factice pour definir les dof de un (en gros pour que les condition initiale de problème soit bien nulle)
    Galerkin { [ 0 * Dof{un} , {un} ] ;
      In Air ; Jacobian JVol ; Integration Int ; }
  }
}
}


Resolution {

  { Name MagneSta_phi ;
    System {
      { Name Pre ; NameOfFormulation donne_dir_br ; }
      { Name A ; NameOfFormulation MagSta_phi ; }
    }
    Operation {
      Generate[Pre] ; Solve[Pre] ; SaveSolution[Pre] ;
      Generate[A] ; Solve[A] ; SaveSolution[A] ;
      
    }
  }
}


PostProcessing {
  
  { Name MagSta_phi ; NameOfFormulation MagSta_phi ;
    Quantity {
      { Name b   ;
	Value { Local { [ - mu[] * {d phi} ] ; In Domaine ; Jacobian JVol ; }
	  Local { [ + braimant/Norm[{d phir}]*{d phir} ]    ; In Aimant ; Jacobian JVol ; } } }
      { Name h   ;
	Value { Local { [ - {d phi} ]        ; In Domaine ; Jacobian JVol ; } } }
      { Name br  ; Value { Local { [ braimant/Norm[{d phir}]*{d phir} ]  ; In Aimant ; Jacobian JVol ; } } }
      { Name phi ; Value { Local { [ {phi} ] ; In Domaine ; Jacobian JVol ; } } }
      { Name phir ; Value { Local { [ {phir} ] ; In Aimant ; Jacobian JVol ; } } }
      { Name grad_un ; Value { Local { [ -{d un} ] ; In Air ; Jacobian JVol ; } } }
      { Name f ; Value { Integral { [ - TM[-mu[] * {d phi}] * {d un} ] ;// calcul force avec tenseur trouvé
	    In Couche_Elts ; Jacobian JVol ; Integration Int ; } } }
      { Name fx ; Value { Integral { [ CompX[- TM[-mu[] * {d phi}] * {d un} ] ] ;
	    In Couche_Elts ; Jacobian JVol ; Integration Int ; } } }
      { Name fy ; Value { Integral { [ CompY[- TM[-mu[] * {d phi}] * {d un} ] ] ;
	    In Couche_Elts ; Jacobian JVol ; Integration Int ; } } }
      { Name fz ; Value { Integral { [ CompZ[- TM[-mu[] * {d phi}] * {d un} ] ] ;
	    In Couche_Elts ; Jacobian JVol ; Integration Int ; } } }
    }
  }
}

PostOperation { 
  
  { Name MagneSta_phi ; NameOfPostProcessing MagSta_phi;
    Operation {
      Print[ br, OnElementsOf Aimant, File "br.pos" ] ;
      Print[ grad_un, OnElementsOf Couche_Elts, File "normal.pos" ] ;
      Print[ h, OnElementsOf Domaine, File "h.pos" ] ;
      Print[ b, OnElementsOf Domaine, File "b.pos" ] ;
      Echo[ Str["l=PostProcessing.NbViews-1;",
		"View[l].ArrowSizeMax = 100;",
		"View[l].CenterGlyphs = 1;",
		"View[l].VectorType = 4;" ] ,
        File "tmp.geo", LastTimeStepOnly] ;
      Print[ f[Couche_Elts], OnGlobal, Format Table, File "F.dat"  ];
      Print[ fx[Couche_Elts], OnGlobal, Format Table, File "Fx.dat",
	SendToServer "Modèle/Résultats/force en x [N]", Color "Ivory"  ];
      Print[ fy[Couche_Elts], OnGlobal, Format Table, File "Fy.dat",
	SendToServer "Modèle/Résultats/force en y [N]", Color "Ivory"  ];
      Print[ fz[Couche_Elts], OnGlobal, Format Table, File "Fz.dat",
          SendToServer "Modèle/Résultats/force en z [N]", Color "Ivory"  ];  
      
    }
  }  
}


