


AIR=1000;
CIRCUITMAG=1001;
BOBINEALLER=1002;
BOBINERETOUR=1003;
DIRICHLET=1004;
Group{
    Domaine = Region[{AIR,CIRCUITMAG,BOBINEALLER,BOBINERETOUR}];
    Domaine_NonMag = Region[{AIR,BOBINEALLER,BOBINERETOUR}];
    Domaine_Mag = Region[{CIRCUITMAG}];
    
    BobineAller = Region[{BOBINEALLER}];
    BobineRetour = Region[{BOBINERETOUR}];
    Bobines =  Region[{BOBINEALLER,BOBINERETOUR}];
    Dirichlet = Region[{DIRICHLET}];
}
Function{
    mu0 = 4e-7*Pi;
    mur = 500;
    N = 150;
    I = 0.5*0.16/N*2e6;
    Lz = 20e-2;
    nu[#{Domaine_NonMag}] = 1.0/mu0;
    nu[#{Domaine_Mag}] = 1.0/(mu0*mur);
    j[#{BobineAller}] = Vector[0,0,N*I/0.16];
    j[#{BobineRetour}] = Vector[0,0,-N*I/0.16];
}

Jacobian{
    { Name Jvol;
      Case {
        { Region All ; Jacobian Vol ; }
      }
    }
  }
  
  Integration {
    { Name Integ;
      Case { 
        {Type Gauss;
      Case { 
        { GeoElement Line ; NumberOfPoints 2; }
        { GeoElement Triangle ; NumberOfPoints 6; } }
        }
      }
    }
  }

  Constraint {	
    {Name Dirichlet ;
      Case {      
        { Region Dirichlet ; Type Assign ; Value 0. ; }
      }
    }
  }

  FunctionSpace {
    { Name Hrot ; Type Form1 ; 
      BasisFunction { 
        { Name se ; NameOfCoef ae ; Function BF_PerpendicularEdge ; 
            Support Region[{Domaine}]  ; Entity NodesOf[All] ; }
      } 
      Constraint {
        { NameOfCoef ae  ; EntityType NodesOf ; NameOfConstraint Dirichlet ; }
      }
    }
  }

  Formulation {
    { Name Magnetostat ; Type FemEquation ;
      Quantity {
        { Name a  ; Type Local  ; NameOfSpace Hrot ; }
      }
     Equation {
       
        Galerkin { [ nu[]*Dof{Curl a}  , {Curl a} ] ;
          In Domaine ; Jacobian Jvol ; Integration Integ ; }

	Galerkin { [ -j[]  , {a} ] ;
          In Bobines ; Jacobian Jvol ; Integration Integ ; }
	
      }
    }
  }
  Resolution {
    { Name analyse ;
      System {
        { Name Sys ; NameOfFormulation Magnetostat ; }
      }
      Operation {
        Generate[Sys] ; 
        Solve[Sys] ;
        SaveSolution[Sys] ;
      }
    }
  }

  PostProcessing {
    { Name PostProc ; NameOfFormulation Magnetostat ;
      Quantity {	
        { Name a  ; Value { Term { [ {a} ] ; In Domaine ; Jacobian Jvol ; } } }
	{ Name az  ; Value { Term { [ Norm[{a}] ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name b  ; Value { Term { [ {Curl a} ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name h  ; Value { Term { [ nu[]*{Curl a} ] ; In Domaine ; Jacobian Jvol ; } } }
	
	{ Name L ; Value { Integral { [ N*Lz*Norm[{a}]/(0.16)/I ]  ; In Bobines ; 
	      Jacobian Jvol ; Integration Integ ;} } } 
      }
    }
  }
  PostOperation PostOp UsingPost PostProc {
    Print[ a, OnElementsOf Domaine, File "a.pos"] ;
    Print[ az, OnElementsOf Domaine, File "az.pos"] ;
    Echo[ Str["View[1].IntervalsType = 1;", "View[1].NbIso = 30;", "View[1].LightLines = 0;"], 
      File "tmp.geo", LastTimeStepOnly ];
    Print[ b, OnElementsOf Domaine, File "b.pos"] ;
    Print[ h, OnElementsOf Domaine, File "h.pos"] ;
    //Print[ F_TM[Entrefer], OnGlobal, File "force.dat", 
     // SendToServer "Modele/Resultats/1Force par Tenseur moyenné (N)", Color "AliceBlue" ];
    Print[ L[Bobines], OnGlobal, File "inductance.dat", 
      SendToServer "Modele/Resultats/2Inductance (H)", Color "AliceBlue" ];  
  }