

Group{
  Domaine = Region[{1,2}];
  aire = Region[{1}];
  condo = Region[{2}];
  Neumann = Region[{3}];
  Dirichlet = Region[{4}];
  Tension1 = Region[{5}];
  Tension2 = Region[{6}];
  }
 Function{
    beta[#{condo}] = 1.0;
    gamma[#{Neumann}] = 1.0;
  }
  
  Jacobian{
    { Name Jvol;
      Case {
        { Region All ; Jacobian Vol; }
      }
    }
  }
  
  Integration {
    { Name Integ;
      Case { 
        {Type Gauss;
      Case { 
        { GeoElement Line ; NumberOfPoints 2; }
        { GeoElement Triangle ; NumberOfPoints 6; }
        { GeoElement Quadrangle ; NumberOfPoints 4; }
      }
        }
      }
    }
  }
  Constraint {	
    {Name ConditionDirichlet1 ;
      Case {      
        {Region Tension1 ; Type Assign ; Value 0. ;}
      }
    }
    {Name ConditionDirichlet2 ;
        Case {      
          {Region Tension2 ; Type Assign ; Value 50 ;}
        }
    }
    {Name carac ;
        Case {      
          {Region condo ; Type Assign ; Value 1000 ;}
        }
    }
}
  FunctionSpace {
    { Name Hgrad ; Type Form0 ; 
      BasisFunction { 
        { Name sn ; NameOfCoef phi ; Function BF_Node ; 
      Support Region[{Domaine,Tension2}]  ; Entity NodesOf[All] ; }
      } 
      Constraint {
        { NameOfCoef phi  ; EntityType NodesOf ; NameOfConstraint ConditionDirichlet1 ; }
      }
    }
  }
  Formulation {
    { Name Projet_GMSH ; Type FemEquation ;
      Quantity {
        { Name u  ; Type Local  ; NameOfSpace Hgrad ; }
      }
     Equation {
        Galerkin { [ Dof{Grad u}  , {Grad u} ] ;
          In Domaine ; Jacobian Jvol ; Integration Integ ; }
        Galerkin { [  -beta[] , {u} ] ;
          In condo ; Jacobian Jvol ; Integration Integ ; }     
        Galerkin { [ -gamma[] , {u} ] ; 
            In Neumann ; Jacobian Jvol ; Integration Integ ; }
      }
    }
  }
  Resolution {
    { Name analyse ;
      System {
        { Name Sys ; NameOfFormulation Projet_GMSH ; }
      }
      Operation {
        Generate[Sys] ; 
        Solve[Sys] ;
        SaveSolution[Sys] ;
      }
    }
  }
  PostProcessing {
    { Name PostProc ; NameOfFormulation Projet_GMSH ;
      Quantity {	
        { Name u  ; Value { Term { [ {u} ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name Grad_u  ; Value { Term { [ {Grad u} ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name normu ; Value { Integral { [ Norm[{u}] ]  ; In Domaine ; 
          Jacobian Jvol ; Integration Integ ;} } } 
      }
    }
  }
  
  PostOperation PostOp UsingPost PostProc {
    Print[ Grad_u, OnElementsOf Domaine, File "gradu.pos"] ;
    Print[ u, OnElementsOf Domaine, File "u.pos"] ;
    Print[ normu[Domaine], OnGlobal, File "normu.dat", 
      SendToServer "Modele/Resultats/1Norme (u)", Color "AliceBlue" ];
  }
    