# Ventouse magnétique

> **But du sujet :** Étudier et calculer la force d'un électroaimant de type « ventouse magnétique » (verrouillage magnétique de porte).
>      
>  **Notions abordées :**
>  	* Problème 2D Plan,
>  	* Définition des matériaux ferromagnétiques en linéaire et non-linéaire,
>  	* Calculs de force (Tenseur de Maxwell, Tenseur moyenné, dérivation de la coénergie).

Nous allons maintenant nous intéresser à un dispositif particulièrement répandu en électrotechnique : un électroaimant. L'application visée est une ventouse magnétique servant à verrouiller une porte de Hall d'immeuble ou d'hôpital par exemple. Un exemple de produit fini est donnée par la figure ci-dessous (vous pouvez passer le voir, il est dans mon bureau : 110 Rouge) :

![Ventouse](./figures/ventouse.jpg "Ventouse 500 daN")

Le circuit magnétique en E sur lequel il est construit, est :

![Circuit magnétique ventouse](./figures/circuit_mag_ventouse.jpg "Circuit magnétique de la ventouse")

On remarquera qu'il est constitué de tôles feuilletées même si, pour ce type d'application alimentée en continu, ça ne sert à rien.

Une représentation schématique du dispositif est alors :

![Schéma dispositif](./figures/schema_ventouse.svg "Représentation schématique du dispositif")


## Premières simulations en régime linéaire 

**➤ Créez le script MATLAB ou Python permettant de résoudre ce problème en linéaire.** 

Les valeurs des paramètres sont données par la table suivante :

| Paramètres | Unité | Valeurs |
|:----------:|:-----:|:-------:|
| aE | cm | 1 |
| bE | cm | 1 |
| hE | cm | 2 |
| e | mm | 1 |
| Ep | cm | 1,5 |
| Lz | cm | 20 | 
| Ic | A | 0,5 |
| N | - | 250 |

> **Remarque :** Pensez à définir votre problème comme 2D cartésien de profondeur Lz.   
>     
> * *MATLAB :*
> ```Matlab
> mi_probdef(0,'millimeters','planar',1e-8,Lz);  % 1e-8 = precision du solveur
> ```
> * *Python :*
> ```Python
> femm.mi_probdef(0,'millimeters','planar',1e-8,Lz) # 1e-8 = precision du solveur
> ```

Et les matériaux magnétiques sont définis par celle-ci :

| Matériau | Type | Nom | Nom FEMM | \\(\mu_r\\)
|:-------------------:|:---:|:---:|:---:|:---:|
| Circuit magnétique | Tôles | M530 | M-45 Steel | 4689 |
| Plaque | Massif | C10 | 1010 Steel | 902 | 


> **Astuce :** Dans FEMM, vous pouvez définir un retour de courant en affectant un nombre de tours négatif à un bloc associé à un circuit.


### Compléments sur le calcul de force 

Pour calculer les forces s'exerçant sur les pièces mobiles, FEMM utilise le tenseur des contraintes électromagnétique de Maxwell. 

Le terme général de celui-ci dans l'air (contribution purement magnétique) est :
\\[T_{i\\,k} = \frac{1}{\mu_0}\\,b_i\\,b_k -\frac{\delta_{i k}}{2\\,\mu_0}|\\!|{\bf b}|\\!|^2 ~ ; ~ ~ ~ i,k = x,y,z\\]

Dans notre cas particulier, l'expression du tenseur est : 
\\[\overline{\overline{{\bf T}}} = \frac{1}{2\\,\mu_0}\begin{pmatrix}b_x^2-b_y^2 & 2\\, b_x b_y & 0 \\\\ 2\\,b_x b_y & b_y^2-b_x^2 & 0 \\\\ 0 & 0 & - (b_x^2 + b_y^2 )\end{pmatrix}\\]

On déduit la force par : 

\\[ {\bf F} = \iint_{S}\\,\overline{\overline{{\bf T}}}\cdot{\bf d S}\\]

Où \\(S\\) est une surface fermée située dans l'air et entourant la pièce mobile. Puisque notre problème est 2D, cette surface sera représentée par un parallélépipède rectangle (pavé droit) de longueur \\(L_z\\) et s'appuyant sur un contour fermé \\(C\\), et : 

\\[ {\bf F} = L_z\\,\oint_{C}\\,\overline{\overline{{\bf T}}}\cdot{\bf n}\\, \text{d}l\\]

Dans FEMM, vous pourrez :
1. Créer un contour d'intégration en utilisant récursivement l'instruction `mo_addcontour(x,y)` (n'oubliez pas de le fermer), puis intégrer l'expression du tenseur avec un `mo_lineintegral(3)`. 
	> **Remarque :** On pensera à définir le contour dans le sens direct pour que la normale soit bien une normale sortante à la surface. 
2. Sélectionner le bloc correspondant à la plaque et utiliser la commande `mo_blockintegral(19)`.     
	Cette façon de procéder est la plus intéressante car elle permet de calculer une **valeur moyennée** de la force par la technique dite de la « coquille d'œuf » (*eggshell*). FEMM va automatiquement choisir une bande d'éléments de l'air entourant le bloc, calculer l'intégrale sur plusieurs contours traversant cette bande, et calculer la moyenne des valeurs ainsi obtenues. Ceci permet de filtrer les éventuelles erreurs d'interpolation pouvant intervenir sur les points d'un unique contour. 
	
**➤ Testez les deux méthodes sur votre premier calcul.**

**➤ À l'aide du théorème d'Ampère, développez un modèle analytique approché permettant de calculer la force, et vérifiez la concordance des ordres de grandeur.**


### Force en fonction de la position

Une fois que les calculs précédents validés, nous allons tracer la force en fonction de la position de la plaque (entrefer \\(e\\) variable). 

Pour cela, faites varier \\(e\\) entre 1 et 20 mm, et calculez la force pour chaque position. Nous calculerons également la coénergie du système afin d'obtenir une troisième méthode de calcul de la force par la dérivation de la coénergie. En effet, dans notre cas, nous avons aussi :

\\[F_e = \frac{\partial~\widetilde{W}}{\partial\\,e}\\]

Où \\(F_e\\) est la valeur de la force dans la direction de la coordonnée généralisée \\(e\\) (dans notre cas : \\(-{\bf u_y}\\)). 

> **Conseil d'implantation :** 
> 1. Commencez par l'entrefer le plus grand pour que la boîte infinie soit bien adaptée pour ce cas géométrique.
> 2. Bouclez seulement sur la résolution du problème en ayant préalablement déplacé la plaque avec un `mi_movetranslate` ou `mi_movetranslate2`. Une bonne astuce consiste à mettre préalablement les lignes et le blocklabel dans le même groupe, et translater le groupe. 
> 3. Approximez la dérivée de la coénergie par : \\[F_y\left(e_k-\frac{\Delta e}{2}\right) = \frac{\widetilde{W}(e_{k+1})-\widetilde{W}(e_{k})}{\Delta e}\\]
> où : \\(e_{k+1} = e_k -\Delta e\\).

**➤ Tracez la courbe \\(|F_y(e)|\\) en superposant les valeurs obtenues par les 3 méthodes.**


## Régime saturé

Maintenant, nous allons nous intéresser au cas plus réaliste où le comportement de chaque matériau ferromagnétique est modélisé par sa courbe B(H). 

Comme précédemment, si vous désirez utiliser un matériau dont la caractéristique magnétique est non-linéaire, vous pouvez :
1. Créer votre matériau avec la commande `mi_addmaterial`, puis ajouter point par point ceux de la courbe correspondante avec `mi_addbhpoint('nom',B,H)`. 
2. Importer directement un matériau de la librairie avec `mi_getmaterial`. Par défaut, cette dernière contient beaucoup de matériaux utiles, si celui dont on a besoin s'y trouve, c'est la méthode que je vous conseille. 

**➤ Tracez la courbe \\(|F_y(Ic)|\\) (pour \\(e = 1\\,\text{mm}\\)) afin de voir l'influence de la saturation.** Pour cela : faites une première boucle sur Ic en linéaire comme dans les questions précédentes, puis refaites les calculs après avoir remplacé vos matériaux magnétiques par les vrais, c'est-à-dire ceux importés depuis la librairie de FEMM. 

> **Conseil d'implantation :** 
> Une fois que votre calcul en non-linéaire fonctionne, bouclez seulement sur la résolution précédée d'un `mi_modifycircprop` ou `mi_setcurrent` permettant de modifier la valeur du courant de circuit. 



## Bonus (facultatif)

Reprendre l'étude pour une géométrie cylindrique comme les ventouses de retenue de porte coup-feu du couloir des salles de TP (vous pourrez ainsi mesurer approximativement les différentes tailles du circuit magnétique) :

![Ventouse cylindrique](./figures/ventouse_cyl.jpg "Exemple de ventouse cylindrique à l'ENSEM")

![Circuit magnétique cylindrique](./figures/circuit_mag_cyl.jpg "Circuit magnétique de ventouse cylindrique") 

