---
title: "Conditions d'interfaces"
draft: false
weight: 10
markup: "goldmark"
math: "true" 
---


## Composantes normales

Considérons deux milieux $\\#1$ et $\\#2$ séparés par une surface $S$, la normale à la surface étant dirigée de $\\#1$ vers $\\#2$. Pour un infiniment petit quelconque $u$, on définit un petit cylindre de volume $v_c$, de rayon $r = o(u)$ et de hauteur $l = o(u^2)$ centré sur $S$.  
Une représentation schématique est donnée par la figure ci-dessous.

{{< figure src="../../images/figures/schema_bn.svg" title="Représentation schématique de la configuration considérée (pour les composantes normales)." >}}

En notant $s_1$ et $s_2$ les bases du cylindre contenues respectivement dans $\\#1$ et $\\#2$, et $s_l$ sa surface latérale, on a :
$$\left\\{\begin{aligned}s_1 = s_2 = s = o(u^2)\\\ s_l = o(u^3)\end{aligned}\right.$$

--- 

### Continuité de la composante normale de ${\bf b}$

Appliquons la conservation du flux à notre cylindre :
$$\oiint_{\partial v_c} {\bf b}\cdot{\bf d S} = 0$$

Soit, en développant et en multipliant par $\frac{1}{s}$ :

$$\frac{1}{s} \iint_{s_1} {\bf b}\cdot(-{\bf n_{12}})~ \text{d} S + \frac{1}{s} \iint_{s_2} {\bf b}\cdot{\bf n_{12}}~\text{d} S + \frac{1}{s} \iint_{s_l} {\bf b}\cdot{\bf d S} = 0$$

Or : 

$$\frac{1}{s} \iint_{s_l} {\bf b}\cdot{\bf d S} \leq \max_{s_l}(|\\!|{\bf b}|\\!|)\\,\frac{s_l}{s} = o(u)$$

Et :
$$\left\\{\begin{aligned}\lim_{u \to 0}\left(\frac{1}{s} \iint_{s_1} {\bf b}\cdot(-{\bf n_{12}})~ \text{d} S\right) &= - {\bf b_1}\cdot{\bf n_{12}}\\\ \lim_{u \to 0}\left(\frac{1}{s} \iint_{s_2} {\bf b}\cdot{\bf n_{12}}~\text{d} S\right) &= {\bf b_2}\cdot{\bf n_{12}}\end{aligned}\right.$$

Où ${\bf b_1}$ et ${\bf b_2}$ sont les valeurs de l'induction au centre du cylindre approché respectivement depuis les milieux $\\#1$ ou $\\#2$.

Ainsi par passage à la limite dans l'expression générale, on obtient :
$$\boxed{{\bf n_{12}}\cdot({\bf b_2}-{\bf b_1}) = 0}$$

On a donc **continuité de la composante normale de l'induction magnétique** ${\bf b}$ à travers la surface.

---

### Saut de la composante normale de ${\bf d}$

Appliquons le raisonnement précédent en partant du théorème de Gauss :

$$\oiint_{\partial v_c} {\bf d}\cdot{\bf dS} = \iiint_{v_c} \rho_q\\,\text{d} V$$

Le terme de gauche peut-être traité exactement de la même façon que pour ${\bf b}$. Pour le terme de droite, on peut écrire :

$$\frac{1}{s} \iiint_{v_c} \rho_q\\,\text{d} V = \frac{1}{s} \iint_{s} \left(\int_{-\frac{l}{2}}^{\frac{l}{2}} \rho_q\\,\text{d}{l}\right) \text{d} S$$
 
En définissant localement la densité surfacique de charge $\sigma_q$ (densité de charge portée par la surface $s$, en $\text{C}\cdot\text{m}^{-2}$) par : 

$$\sigma_q = \lim_{l \to 0} \int_{-\frac{l}{2}}^{\frac{l}{2}} \rho_q\\,\text{d}{l}~,$$

par passage à la limite ($u \to 0$), on obtient : 

$$\boxed{{\bf n_{12}}\cdot({\bf d_2}-{\bf d_1}) = \sigma_q}$$

On a donc un **saut de la composante normale de** ${\bf d}$ à travers $S$. 

{{% notice note %}}
On trouve des densités surfaciques de charge dans tout conducteur à l'équilibre électrostatique. 
{{% /notice %}}

{{% notice tip %}}
En l'absence de densité surfacique de charge : on a évidemment continuité de la composante normale de l'induction électrique ${\bf d}$. 
{{% /notice %}} 

---
 
### Continuité de la composante normale de ${\bf j}$

**Dans l'ARQS**, puisque $\text{div}\\,{\bf j} = 0$, on peut appliquer le même raisonnement que pour ${\bf b}$, et ainsi :

$$\boxed{{\bf n_{12}}\cdot({\bf j_2}-{\bf j_1}) = 0}$$

En particulier, sur le bord d'un conducteur isolé, ${\bf j_2}$ étant nulle à l'extérieur, on en déduit que la densité de courant est tangente à la surface. 
 
---

## Composantes tangentielles

En prenant une coupe de la configuration précédente, on obtient celle décrite par la figure ci-après. 

{{< figure src="../../images/figures/schema_ht.svg" title="Représentation schématique de la configuration considérée (pour les composantes tangentielles)." >}}

Dans ce plan de coupe, on choisit arbitrairement un chemin rectangulaire $\mathscr{C}$, de sommets $A$, $B$, $C$ et $D$. Les segments $AB$ et $CD$ sont de longueurs $l_1 = l_2 = l = o(u)$ et portés par un **vecteur unitaire quelconque orthogonal à la normale à la surface :** ${\bf u_l}\perp{\bf n_{12}}$. Les segments $BC$ et $DA$ sont de longueur $\alpha = o(u^2)$ et portés par ${\bf n_{12}}$. 

--- 

### Continuité de la composante tangentielle de ${\bf e}$

La loi de Lenz-Faraday appliquée au contour $\mathscr{C}$ et multipliée par un facteur $\frac{1}{l}$, nous donne :

$$\frac{1}{l} \oint_{\mathscr{C}} {\bf e}\cdot{\bf dl} = \frac{1}{l} \iint_{s_l} -\frac{\partial\\,{\bf b}}{\partial t}\cdot{\bf d S}$$

En développant le membre de gauche, on obtient :

$$\begin{aligned}\frac{1}{l} \oint_{\mathscr{C}} {\bf e}\cdot{\bf dl} = \frac{1}{l} \int_{l_1}{\bf e}\cdot{\bf u_l}\\,\text{d} l ~+ &\frac{1}{l} \int_{l_2}{\bf e}\cdot(-{\bf u_l})\\,\text{d} l \\\ &+ \underbrace{\frac{1}{l}\left(\int_{B}^{C}{\bf e}\cdot{\bf n_{12}}\\,\text{d} l + \int_{D}^{A}{\bf e}\cdot(-{\bf n_{12}})\\,\text{d} l\right)}\_{\lambda}\end{aligned}$$
Or : 

$$\lambda \leq \left(\max_{BC}(\|\\!\|{\bf e}\|\\!\|) + \max_{DA}(\|\\!\|{\bf e}\|\\!\|)\right)\frac{\alpha}{l} = o(u) $$

De plus : 

$$\begin{aligned}\left\|\frac{1}{l} \iint_{s_l} -\frac{\partial\\,{\bf b}}{\partial t}\cdot{\bf d S} \right| = \frac{1}{l} &\iint_{s_l} \frac{\partial\\,{\bf b}}{\partial t}\cdot({\bf u_l}\wedge{\bf n_{l2}})\\,\text{d} S \\\ &\leq \max_{s_l}\left(\left\|\\!\left\|\frac{\partial\\,{\bf b}}{\partial t}\right\|\\!\right\|\right)\\,\alpha = o(u^2)\end{aligned}$$

Finalement, on a :

$$\frac{1}{l} \int_{l_1}{\bf e}\cdot{\bf u_l}\\,\text{d} l + \frac{1}{l} \int_{l_2}{\bf e}\cdot(-{\bf u_l})\\,\text{d} l + o(u) = o(u^2)$$

Par passage à la limite ($u \to 0$), on obtient :

$$({\bf e_1} - {\bf e_2})\cdot{\bf u_l} = 0$$

Où ${\bf e_1}$ et ${\bf e_2}$ sont les valeurs du champ électrique au centre du rectangle approché respectivement depuis les milieux $\\#1$ ou $\\#2$.

La relation précédente étant valable **quelque soit le vecteur** ${\bf u_l}\perp{\bf n_{12}}$ choisi, on peut en déduire :

$$\boxed{{\bf n_{12}}\wedge({\bf e_2}-{\bf e_1}) = {\bf 0}}$$

On a donc **continuité de la composante tangentielle du champ électrique.**

---

### Saut de la composante tangentielle de ${\bf h}$

En appliquant le théorème d'Ampère sur $\mathscr{C}$ et en multipliant chaque terme par un facteur $\frac{1}{l}$ on obtient :

$$\frac{1}{l} \oint_{\mathscr{C}} {\bf h}\cdot{\bf dl} = \frac{1}{l} \iint_{s_l} {\bf j}\cdot{\bf d S}$$

Le terme de gauche peut être traité exactement de la même manière que dans le paragraphe précédent. 

Intéressons-nous au terme de droite :

$$\begin{aligned}\frac{1}{l} \iint_{s_l} {\bf j}\cdot{\bf d S} &= \frac{1}{l} \iint_{s_l} {\bf j}\cdot({\bf u_l}\wedge{\bf n_{12}})\\,\text{d} S \\\ &= \frac{1}{l} \int_l \left(\int_{\frac{-\alpha}{2}}^{\frac{\alpha}{2}} {\bf j}\\,\text{d} \alpha\right)\cdot({\bf u_l}\wedge{\bf n_{12}})\\,\text{d} l\end{aligned}$$

En définissant localement la densité surfacique de courant ${\bf j_s}$ (densité de courant portée par la surface $S$, en $\text{A}\cdot\text{m}^{-1}$) par :

$${\bf j_s} = \lim_{\alpha\to 0}\int_{\frac{-\alpha}{2}}^{\frac{\alpha}{2}} {\bf j}\\,\text{d} \alpha ~~~,$$

on obtient, par passage à la limite ($u\to 0$) : 

$$({\bf h_1}-{\bf h_2})\cdot{\bf u_l} = {\bf j_s}\cdot({\bf u_l}\wedge{\bf n_{12}}) = {\bf u_l}\cdot({\bf n_{12}}\wedge{\bf j_s})$$

Où ${\bf h_1}$ et ${\bf h_2}$ sont les valeurs du champ magnétique au centre du rectangle approché respectivement depuis les milieux $\\#1$ ou $\\#2$, et ${\bf j_s}$ y est également la valeur de la densité surfacique de courant. 

Ainsi, **pour tout** ${\bf u_l}\perp{\bf n_{12}}$ :

$$({\bf h_1}-{\bf h_2})\cdot{\bf u_l} = ({\bf n_{12}}\wedge{\bf j_s})\cdot{\bf u_l}$$

La densité superficielle de courant ${\bf j_s}$ étant portée par la surface $S$, et donc étant orthogonale à ${\bf n_{12}}$, on peut en déduire : 

$$\boxed{{\bf n_{12}}\wedge({\bf h_2}-{\bf h_1}) = {\bf j_s}}$$

On a donc un **saut de la composante tangentielle de** ${\bf h}$ à travers $S$. 

{{% notice note %}}
En réalité, une densité surfacique de courant n'existe pas physiquement : on a toujours une densité de courant volumique. Cependant, dans certains cas, l'épaisseur de la zone où circule cette densité volumique est suffisamment faible pour l'assimiler à une densité surfacique. On peut citer deux cas fréquents : dans une plaque ou un tube très mince ; sur les bords d'un conducteur siège de courants induits à « haute fréquence ». 
{{% /notice %}}

{{% notice tip %}}
Sans densité superficielle de courant (donc souvent), il y a continuité de la composante tangentielle de ${\bf h}$. 
{{% /notice %}}




