---
title: "Lois de comportement"
draft: false
weight: 4
markup: "goldmark"
math: "true" 
---
Dans un milieu matériel donné, les différents champs constituant le champ électromagnétique sont liés entre eux par les caractéristiques physiques du matériau. Ces relations sont modélisées par ce qu'on appelle les **lois de comportement**.  

En ce qui nous concerne, on en distinguera trois types :
* les [**lois de comportement magnétique**](#lois-de-comportement-magnétique-bf-bbf-h)
* les [**lois de comportement électrique**](#lois-de-comportement-électrique-bf-ebf-j)
* les [**lois de comportement diélectrique**](#lois-de-comportement-diélectriques-bf-dbf-e)
--- 

## Lois de comportement magnétique ${\bf b}({\bf h})$ 

### Matériaux non-magnétiques (amagnétiques)

Dans un milieu non magnétique tel que le vide (ou l'air), mais aussi dans les isolants ou conducteurs électriques classiques (cuivre, aluminium, etc...), l'induction ${\bf b}$ est directement proportionnelle au champ magnétique ${\bf h}$ par : 
$$\boxed{{\bf b} = \mu_0\\,{\bf h}}$$
Où $\mu_0$ est la perméabilité magnétique du vide :
$$ \mu_0 = 4 \pi~10^{-7}~~\text{H}\cdot\text{m}^{-1} $$

{{% notice info %}}
En réalité, hormis le vide, un matériau est souvent légèrement diamagnétique (tendance à repousser le champ d'induction) ou paramagnétique (tendance à attirer le champ d'induction). On a une relation de type ${\bf b} = \mu_0\\,\mu_r~{\bf h}$ avec $\mu_r$ très légèrement inférieur ou supérieur à 1. En pratique, ces effets sont suffisamment faibles pour être négligés.  
{{% /notice %}}

### Matériaux ferromagnétiques

Ce sont des matériaux dans lesquels apparaît une aimantation ${\bf m}$ (en $\text{A}\cdot\text{m}^{-1}$) lorsqu'ils sont soumis à un champ magnétique ${\bf h}$.  
La loi correspondante est :
$${\bf b} = \mu_0\\,({\bf h} + {\bf m})$$
L'évolution de la valeur de l'induction, dans la direction privilégiée, en fonction de celle du champ décrit alors un cycle d'hystérésis comme sur la figure ci-dessous :
{{< figure src="../../images/figures/cycle_pol.svg" title="Exemple de cycle d'hystérésis" >}} 
Sur la figure, est également représentée la courbe de première aimantation en bleue, ainsi que :
* la valeur de l'induction rémanente $B_r$,
* la valeur du champ coercitif $H_c$.

L'aimantation ${\bf m}$ s'exprime elle-même en fonction de ${\bf h}$ par :
$$ {\bf m} = {\bf m_0} + \chi_m\\,{\bf h}$$ 
avec :
* $\chi_m$ : susceptibilité magnétique du matériau (sans unité, peut dépendre de ${\bf h}$),
* ${\bf m_0}$ :  aimantation permanente du matériau (en $\text{A}\cdot\text{m}^{-1}$). 

{{% notice info %}}
On pourrait retrouver les expressions reliant ${\bf m_0}$ et $\chi_m$ à $B_r$ ou $H_c$.
{{% /notice %}}


#### Matériaux ferromagnétiques doux

Les matériaux doux sont caractérisés par un cycle très étroit, comme par exemple : 
{{< figure src="../../images/figures/cycleetroit.svg" title="Exemple de cycle d'hystérésis pour un matériau doux" >}}

Les valeurs de champ coercitif ou d'induction rémanente sont suffisamment faibles pour que le cycle puisse être assimilé à une courbe passant par l'origine, dont l'allure peut se représenter comme ci-dessous :
{{< figure src="../../images/figures/courbe_bdeh.svg" title="Exemple de courbe B(H)" >}}

L'aimantation permanente du matériau est négligeable, et on en déduit :
$$\boxed{{\bf b} = \mu_0\\,\underbrace{(1+\chi_m)}_{\mu_r}\\,{\bf h} = \mu\\,{\bf h}}$$
$\mu$ est la perméabilité magnétique du matériau (en $\text{H}\cdot\text{m}^{-1}$), elle dépend généralement du champ : $\mu({\bf h})$. 

Dans la suite, nous utiliserons deux types de modèles :
1. Le **modèle linéaire** : le plus simple, qui consiste à approximer la courbe par sa pente à l'origine. Ainsi la perméabilité est considérée comme constante égale à $\mu_0\\,\mu_r$ où la valeur de la perméabilité relative $\mu_r$ est celle correspondant à de faibles valeurs de champ. 
2. Le **modèle non-linéaire** : lorsque les champs atteignent des valeurs conséquentes, le modèle précédent n'est plus satisfaisant et on utilise directement la courbe $B(H)$ ci-dessus. En général, elle est traitée par interpolation de valeurs tabulées issues de la mesure. 

C'est ce type de matériaux qui est utilisé pour les circuits magnétiques des applications qui nous intéresseront : inductances, transformateurs, actionneurs, machines tournantes...  

#### Matériaux ferromagnétiques durs (aimants)

À l'inverse des précédents, les ferromagnétiques durs sont caractérisés par un cycle d'hystérésis très large, comme :
{{< figure src="../../images/figures/cycleaimant.svg" title="Exemple de cycle d'hystérésis pour un matériau dur" >}} 
En plus des grandeurs précédentes, on notera la valeur remarquable $H_{ci}$ correspondant au champ coercitif irréversible (en $\text{A}\cdot\text{m}^{-1}$). Cette valeur est la valeur de champ au delà de laquelle l'aimantation permanente s'inverse. 

Dans la suite, on se situera toujours sur la partie linéaire correspondant à la partie haute du cycle. Par substitution, on a :
$$ {\bf b} = \mu_0\\,({\bf h}+\chi_m\\,{\bf h}+{\bf m_0})$$
Qui s'écrit :
$$\boxed{{\bf b} = \mu_0\underbrace{(1+\chi_m)}\_{\mu_{ra}}\\,{\bf h}+\underbrace{\mu_0\\,{\bf m_0}}\_{{\bf b_r}}}$$
Avec :   
* $\mu_{ra}$ : perméabilité relative de l'aimant (légèrement supérieure à 1)
* ${\bf b_r}$ : induction rémanente (vectorielle)

{{% notice note %}}
Pour compléments, je vous encourage à aller voir cette [**petite vidéo**](https://ultv.univ-lorraine.fr/video/9478-aimant-permanent) réalisée par mon ancien collègue de bureau, le Prof. Denis Netter et accessible sur le serveur de vidéos de l'Université de Lorraine [**ULTV**](https://ultv.univ-lorraine.fr/).   
**Je l'incruste également ci-dessous (avec son autorisation) :**
{{% /notice %}}
{{< rawhtml >}}
<div style="position: relative; text-align:center; background-color: #e7f2fa; max-width:640px; margin-right: auto;margin-left: auto;">
<iframe src="https://ultv.univ-lorraine.fr/video/9478-aimant-permanent/?is_iframe=true" width="100%" height="360" style="padding:0; margin:0; border:0" allowfullscreen ></iframe>	
</div>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/iframe-resizer/4.3.1/iframeResizer.min.js" integrity="sha512-ngVIPTfUxNHrVs52hA0CaOVwC3/do2W4jUEJIufgZQicmY27iAJAind8BPtK2LoyIGiAFcOkjO18r5dTUNLFAw==" crossorigin="anonymous"></script>
  <script>
    iFrameResize({}, '#iframe-jacobian')
  </script>
{{< /rawhtml >}}

--- 

## Lois de comportement électrique ${\bf e}({\bf j})$

Elles sont valables pour des matériaux conducteurs électriques. On peut distinguer deux cas. 

### Milieux conducteurs ohmiques 

Cette catégorie correspondant à l'ensemble des conducteurs que nous verrons par la suite : principalement des métaux comme le cuivre, l'aluminium, le laiton, les aciers, etc...

La loi de comportement, y est simplement :
$$\boxed{{\bf e} = \rho\\,{\bf j}}$$
où $\rho$ est la résistivité électrique du matériau (en $\Omega\cdot\text{m}$).   
On pourra éventuellement lui préférer la relation inverse (strictement équivalente) :
$$\boxed{{\bf j} = \sigma\\,{\bf e}}$$
avec $\sigma = \frac{1}{\rho}$, la conductivité électrique du milieu (en $\text{S}\cdot\text{m}^{-1}$). 

Souvent, les deux relations ci-dessus ne sont pas linéaires car la résistivité et (donc) la conductivité dépendent fortement de la température. Par exemple, pour la conductivité du cuivre : 
{{< figure src="../../images/figures/sigmadeT.svg" title="Évolution de la conductivité du cuivre en fonction de la température" >}}


### Milieux supraconducteurs

Ce sont des matériaux qui, dans les bonnes conditions (de température et de champs) présentent une résistivité électrique nulle ou quasi-nulle. Il sont caractérisés par une loi de comportement du type :
$$ {\bf e} = E_c \left(\frac{|\\!|{\bf j}|\\!|}{J_c}\right)^n \frac{{\bf j}}{|\\!|{\bf j}|\\!|}$$
où $E_c$ et $J_c$ sont respectivement le champ et la densité de courant critiques du matériau. 
{{% notice info %}}
En réalité, la loi ci-dessus fait intervenir d'autre phénomènes couplés car $J_c$ et $n$ dépendent des valeurs de l'induction et de la température.   
Mais, dans le cadre de ce cours, nous n'aborderons malheureusement pas l'étude des supraconducteurs faute de temps...
{{% /notice %}}

--- 

## Lois de comportement diélectriques ${\bf d}({\bf e})$

Un milieu diélectrique est un milieu isolant (non-conducteur du courant) qui peut se polariser électriquement lorsqu'il est soumis à un champ électrique (il est constitué de dipôles électriques). C'est le cas par exemple du verre, de céramiques (dont les céramiques piézoélectriques), du polypropylène, du mica, du téflon, etc...  D'un point de vue « Loi de comportement », on peut faire une analogie avec les milieux magnétiques précédents. 

### Matériaux non-diélectriques

Dans le cas du vide, ou de nombreux autres milieux non-diélectriques comme les conducteurs ou matériaux magnétiques. La relation entre l'induction et le champ électrique est simplement : 
$$\boxed{{\bf d} = \varepsilon_0\\,{\bf e}}$$
où $\epsilon_0$ est la permittivité électrique du vide (en $\text{F}\cdot\text{m}^{-1}$), dont la valeur se déduit de la relation :
$$ \varepsilon_0\\,\mu_0\\,c^2 = 1$$

{{% notice tip %}}
En prenant $3\cdot 10^8~\text{m}\cdot\text{s}^{-1}$ pour la vitesse de la lumière, on approxime souvent $\varepsilon_0$ par :
$$ \varepsilon_0 = \frac{1}{36\\,\pi} 10^{-9} ~~\text{F}\cdot\text{m}^{-1}$$
{{% /notice %}}

### Matériaux diélectriques

Comme pour l'aimantation des matériaux magnétiques, il apparaît une polarisation électrique ${\bf p}$ dans les diélectriques lorsqu'ils sont soumis à un champ électrique ${\bf e}$.   
La loi donnant l'induction ${\bf d}$ est alors :
$$ {\bf d} = \varepsilon_0\\,{\bf e}+{\bf p}$$
La polarisation peut s'écrire sous la forme :
$$ {\bf p} = \varepsilon_0\\,\chi_e\\,{\bf e} + {\bf p_0}$$
avec :
* $\chi_e$ : susceptibilité électrique du matériau (sans unité),
* ${\bf p_0}$ : polarisation permanente du matériau (en $\text{V}\cdot\text{m}^{-1}$), correspond aux matériaux dit ferroélectriques. 

Ainsi, dans une direction privilégiée, la valeur de l'induction en fonction de celle du champ électrique décrit elle-aussi un cycle comme le montre la figure ci-dessous :
{{< figure src="../../images/figures/cycle_pol_de.svg" title="Exemple de cycle d'hystérésis d'un diélectrique" >}}

Dans le cadre de ce cours, nous ne intéresserons qu'aux cas linéaires où ${\bf p_0} = {\bf 0}$.   
On aura donc :
$$\boxed{{\bf d} = \varepsilon_0\\,\underbrace{(1+\chi_e)}_{\varepsilon_r}\\,{\bf e} = \varepsilon\\,{\bf e}}$$
où $\varepsilon_r$ est la permittivité relative du matériau considéré. 

--- 

{{% notice info %}}
Nous avons volontairement éviter de trop détailler cette (déjà trop longue) partie car ce n'est pas l'objectif de l'EC. Nous aurions pu, par exemple, aborder des notions telles que l'anisotropie de certains matériaux ou des couplages multiphysiques supplémentaires (effet Hall, piézoélectricité, etc...), ou alors discuter des semi-conducteurs.   
Pour des compléments, je vous renvoie à l'EC de S7 [**Matériaux pour l'Energie**](https://arche.univ-lorraine.fr/course/view.php?id=43797), partie sur les matériaux pour le Génie Électrique. 
{{% /notice %}}
