---
title: "Régimes harmoniques"
draft: false
weight: 13
markup: "goldmark"
math: "true" 
---

Dans le cas particulier où les sources sont des grandeurs variant sinusoïdalement en fonction du temps $t$, nous pourrons utiliser une représentation complexe qui permet de s'affranchir de la dépendance à la variable $t$ : on l'appelle la **représentation de Fresnel**.

## Transformation complexe

Soit $u(t)$ une fonction sinusoïdale de fréquence $f=\frac{1}{T}$ de la forme : 

$$u(t) = u_{\text{eff}}\\,\sqrt{2}\\,\cos(\omega\\,t+\varphi)$$ 

où :
- $\omega$ est la pulsation ($=2\\,\pi\\,f$)
- $\varphi$ est la phase de $u$
- $u\_{\text{eff}}$ est sa valeur efficace définie par : $$u_{\text{eff}} = \sqrt{\frac{1}{T}\\,\int\_{0}^{T} u(t)^2\\,\text{d} t}$$ 

Nous pouvons alors définir le complexe $\underline{u}$ tel que :

$$\boxed{u(t) \mapsto \underline{u} ~ , ~ \text{tel que : } u(t) = \mathcal{Re}\left[ \sqrt{2} \\, \underline{u} \\, \text{e} ^{j \omega t}\right] ~ , ~~  \text{soit :} ~ ~ \underline{u} = u\_{\text{eff}} \\, \text{e}^{j \varphi}}$$   

La valeur efficace et la phase suffisent à définir le nombre complexe représentatif du signal temporel, et sont respectivement son module et son argument. 

Ainsi, la dérivation par rapport au temps dans le repère complexe devient une simple multiplication par le terme $j \omega$, c'est-à-dire :

$$\frac{\text{d}\\,u}{\text{d} t}(t) \mapsto j \omega \\,\underline{u}$$

Nous pouvons le vérifier :

$$\begin{aligned}\frac{\text{d}\\,u}{\text{d} t}(t) &= - \omega\\,u_{\text{eff}}\\,\sqrt{2}\\,\sin(\omega\\,t+\varphi) \\\\ &= \omega\\,u_{\text{eff}}\\,\sqrt{2}\\,\cos(\omega\\,t+\varphi+\frac{\pi}{2}) \\\\ &= \mathcal{Re}\left[\sqrt{2}\\,\omega\\,u_{\text{eff}}\\, \text{e}^{j(\omega\\,t\varphi+\frac{\pi}{2})}\right] \\\\ &=  \mathcal{Re}\left[\sqrt{2}\\, j \omega \\,u_{\text{eff}} \\,\text{e}^{j\varphi}\\,\text{e}^{j \omega t}\right] \\\\ &=  \mathcal{Re}\left[\sqrt{2}\\, (j \omega \\,\underline{u})\\,\text{e}^{j \omega t}\right]\end{aligned}$$



{{% notice tip %}}
Il existe plusieurs façons de définir les grandeurs complexes à partir d'un même signal $u$. Nous avons choisi d'utiliser un « invariant de puissance » en choisissant la valeur efficace pour le module de $\underline{u}$ (conservation de la norme 2). Nous aurions pu choisir un « invariant d'amplitude » comme les anglo-saxons mais cela s'avère moins pratique à l'usage. 
{{% /notice %}}

{{% notice note %}}
Les complexes ainsi définis ne doivent pas être une nouveauté pour vous : c'est la transformation utilisée depuis toujours en circuits électriques en régime sinusoïdal.
{{% /notice %}}


## Application au champ électromagnétique

Si nous considérons un système électromagnétique alimenté par des tensions ou courants sinusoïdaux (de même pulsation $\omega$, pas trop élevée pour rester dans l'ARQS), les champs en résultant seront eux aussi sinusoïdaux en temps. Nous pouvons donc leur appliquer la transformation complexe précédente.

Par exemple, le champ magnétique sera : 

$$\begin{aligned}{\bf h}(x,y,z,t) &= {\bf h}(x,y,z)\\,\cos(\omega t + \varphi(x,y,z))\\\\ &= \sqrt{2} ~ {\bf h\_{\text{eff}}}(x,y,z)\\,\cos(\omega t + \varphi(x,y,z)) \\\\ &= \mathcal{Re}[\sqrt{2}~{\bf h\_{\text{eff}}}(x,y,z)\\,\text{e}^{j\varphi(x,y,z)}\\,\text{e}^{j\omega\\,t}]\end{aligned}$$

Soit : 
$$\underline{{\bf h}}(x,y,z) = {\bf h\_{\text{eff}}}(x,y,z)\\,\text{e}^{j\varphi(x,y,z)}$$
avec 
$${\bf h\_{\text{eff}}}(x,y,z) = \begin{pmatrix} h\_{x_\text{eff}} \\\\  h\_{y_\text{eff}} \\\\  h\_{z_\text{eff}}\end{pmatrix} = \begin{pmatrix} \sqrt{\frac{1}{T}\\,\int\_{0}^{T} h\_{x}^2(x,y,z,t)\\,\text{d} t}\\\\[1em]\sqrt{\frac{1}{T}\\,\int\_{0}^{T} h\_{y}^2(x,y,z,t)\\,\text{d} t}\\\\[1em]\sqrt{\frac{1}{T}\\,\int\_{0}^{T} h\_{z}^2(x,y,z,t)\\,\text{d} t}\end{pmatrix}$$

Toutes les relations que nous avons vu jusqu'à maintenant pourront s'appliquer en complexe. Nous ne traiterons pas le cas de l'électrostatique (car statique comme son nom l'indique).


### Équations de Maxwell

En régime harmonique, les équations de Maxwell sont : 

$$\left\\{\begin{aligned}\text{div}\\,\underline{\bf b} &= 0 \\\\ {\bf rot\\,\underline{h}} &= \underline{\bf j} \\\\ {\bf rot\\,\underline{e}} &= -j \omega\\,\underline{\bf b}\end{aligned}\right.$$

### Loi de comportement 

En régime harmonique, nous aurons : 

$$\begin{aligned} {\bf \underline{b}} &= \mu_0\mu_r\\,{\bf \underline{h}},~ ~ ~ {\bf \underline{h}} = \nu\\,{\bf \underline{b}} \\\\ {\bf \underline{j}} &= \sigma\\,{\bf \underline{e}},~ ~ ~ {\bf \underline{e}} = \rho\\,{\bf \underline{j}}\end{aligned}$$


{{% notice tip %}}
Les aimants étant des sources statiques, ils ne peuvent être considérés dans des problèmes harmoniques. 
{{% /notice %}}

{{% notice warning %}}
Nous nous intéresserons principalement qu'aux problèmes où les lois de comportement sont linéaires. En effet, le cas non-linéaire est mal défini. Par exemple si ${\bf h}$ est sinusoïdal, alors ${\bf b}$ ne l'est pas en non-linéaire, et inversement (cf figure ci-dessous). Dans ces cas, on ne considère que les valeurs du fondamental des grandeurs (hypothèse du premier harmonique).    
Il existe des techniques permettant de traiter ce type de problèmes de façon approchée (en prenant également l'influence de la largeur du cycle d'hystérésis) en définissant par exemple des perméabilités complexes qui permettent de déduire la valeur du fondamental de l'induction associée (via son module) et le déphasage (via son argument), mais nous ne les traiterons pas dans le cadre de ce cours.
{{% /notice %}}

{{< figure src="../../images/figures/bdeh_courant.svg" title="Forme d'onde du champ et de l'induction magnétique à courant sinusoïdal imposé">}}

{{< figure src="../../images/figures/hdeb_tension.svg" title="Forme d'onde du champ et de l'induction magnétique à tension sinusoïdale imposéé">}}



### Potentiels

Nos potentiels peuvent se définir en complexe également :

$$\begin{aligned}{\bf \underline{b}} &= {\bf rot\\,\underline{a}}\\\\ {\bf \underline{e}} &= -{\bf grad}\\,\underline{v} - j\omega\\,{\bf \underline{a}}\\\\ {\bf \underline{j}} &= {\bf rot\\,\underline{t}}\\\\ {\bf \underline{h}} &= {\bf \underline{t}}-{\bf grad}\\,\underline{\phi}\end{aligned}$$
 
### Lien avec les grandeurs globales

* Courant : $$\underline{I} = \iint_{S_c} {\bf \underline{j}}\cdot{\bf d S}$$
* Flux magnétique : $$\underline{\Phi} = \iint_{S} {\bf \underline{b}}\cdot{\bf d S}$$
* Fém : $$\underline{\mathcal{E}} = - j \omega\\,\underline{\Phi}$$ 
* Densité volumique de pertes Joule : $$p_j = \rho\\,{\bf \underline{j}}\cdot{\bf j}^* = \frac{1}{\sigma}\\,{\bf \underline{j}}\cdot{\bf j}^*$$
{{% notice note %}}
Dans l'expression ci-dessus, on a utilisé $^{\*}$ comme notation pour le complexe conjugué, et on a fait apparaître le produit hermitien. On pourrait facilement montrer que la densité de pertes ainsi définie correspond à : $$p_j = \left\<p\_j(t)\right\> = \frac{1}{T}\int_0^T \rho\\,|\\!| {\bf j}^2(x,y,z,t)|\\!|\\,\text{d}t$$ 
{{% /notice %}}
* Densité volumique d'énergie et coénergie magnétiques : $$w\_{mag} = \frac{1}{2\\,\mu}\\,{\bf \underline{b}}\cdot{\bf b}^* = \frac{1}{2}\\,\mu\\,{\bf \underline{h}}\cdot{\bf h}^*=\widetilde{w}\_{mag}$$

---

{{% notice tip %}}
Dans le cas d'une alimentation alternative mais non-sinusoïdale, le problème peut être résolu par décomposition en série de Fourier, puis en traitant harmonique par harmonique (résolution multi-harmoniques). 
{{% /notice %}}
