---
title: "Exercices de synthèse"
draft: false
weight: 15
markup: "goldmark"
math: "true" 
---


---

## Ex. 1. : Résistance d'une barre cylindrique alimentée en continu{#exo1}

Calculer la résistance d'une barre de cuivre de section circulaire $S$ et de longueur $L$ alimentée par une tension $U$ constante. 

{{% expand "Cliquer pour afficher un indice" %}}
On pourra penser à calculer le potentiel scalaire électrique $v$.  
{{% /expand%}}

{{% expand "Cliquer pour afficher la solution" %}}
$v(z) = \frac{U}{L}\\,z~ $, $ ~ {\bf j} = -\sigma\\,\frac{U}{L}\\,{\bf e_z}~ $, $ ~ R = \rho\\,\frac{L}{S} = \frac{1}{\sigma}\\,\frac{L}{S}$
{{% /expand%}}


---

## Ex. 2. : Condensateurs

Calculer les valeurs de capacités :
1. du condensateur plan suivant : 
![Condensateur plan](../../images/figures/condoplan.svg "Schéma du condensateur plan")
2. du condensateur cylindrique :    
![Condensateur cylindrique](../../images/figures/condocyl.svg "Schéma du condensateur plan")

Les deux étant constitués de deux électrodes séparées par un milieu diélectrique de permittivité relative $\varepsilon_r$. 


{{% expand "Cliquer pour afficher la solution" %}}
* Cas plan : $$C = \varepsilon_0\varepsilon_r\\,\frac{a\\,b}{h}$$
* Cas cylindrique : $$C = \varepsilon_0\varepsilon_r \\, \frac{2\\,\pi\\,h}{\ln\left(\frac{R+e}{R}\right)}$$
{{% /expand%}}

---


## Ex. 3. : Bobine rectangulaire

On considère une bobine rectangulaire à $N$ spires, de longueur $L$ très grande devant sa largeur, telle que représentée ci-dessous : 

{{< figure src="../../images/figures/bob_hypo.png" title="Représentation de la bobine étudiée">}}


On désire calculer le champ d'induction créé par cette bobine, sans négliger le rayon des conducteur (on ne sera donc pas dans le cas d'un circuit filiforme).  

Pour ce faire, nous procéderons par étapes :

1. Après avoir précisé les hypothèses, calculer le champ crée par un conducteur cylindrique de rayon $r\_c$ parcouru par un courant I (ligne unifilaire). 
{{% expand "Cliquer pour afficher un indice" %}}
On pourra penser à utiliser le théorème d'Ampère pour calculer le champ. 
{{% /expand%}}	

2. Dans le langage de votre choix, tracer le champ et les lignes correspondantes :
	1. Par des lignes de courant (*streamline*) ;
	2. En traçant les isovaleurs du potentiel vecteur associé ($a\_z$) après l'avoir déterminé.  
     
	{{% expand "Cliquer pour afficher la solution en MATLAB" %}}
```Matlab
close all; clear; clc

%%% ligne unifilaire
I = 1;        % courant (A)
rc = 1e-3;    % rayon conducteur (m)
adom = 2e-2;  % largeur domaine (m)

npoints = 100; x = linspace(-adom/2,adom/2,npoints); y = x;
bfil = @(x,y) b_fil(x,y,0,0,rc,I); 
[X,Y] = meshgrid(x,y); [BX,BY] = arrayfun(bfil,X,Y);

% trace du champ b et des lignes correspondantes par streamline
nlignes = 6; 
figure(1)
quiver(X,Y,BX,BY,5,'r')
axis equal; hold on; 
startx = linspace(rc,3*adom/4,nlignes); starty = zeros(1,nlignes);
streamline(X,Y,BX,BY,startx,starty)

% mieux : tracé des lignes par isovaleurs du potentiel vecteur
nlignes = 15;
azfil = @(x,y) a_fil(x,y,0,0,rc,I);
AZ = arrayfun(azfil,X,Y);
figure(2)
quiver(X,Y,BX,BY,5,'r')
axis equal; hold on;
contour(X,Y,AZ,nlignes,'LineWidth',2)

% dessin du conducteur
nt = 60; theta = linspace(0,2*pi,nt); 
xt = rc.*cos(theta); yt = rc.*sin(theta);
plot(xt,yt,'k','LineWidth',2)

%#####################
%
%     fonctions
%
%#####################

function [bx,by] = b_fil(x,y,xc,yc,rc,I)
    % induction creee par le fil conducteur
    mu0=4e-7*pi;
    X = x-xc; Y = y-yc;
    r = sqrt(X^2+Y^2);
    if (r<=rc) 
        h_theta = I/(2*pi)*r/rc^2;
    else
        h_theta = I/(2*pi*r);
    end
    normb = mu0*h_theta;
    theta = atan2(Y,X);
    bx = -normb*sin(theta);
    by = normb*cos(theta);
end

function az = a_fil(x,y,xc,yc,rc,I)
    % potentiel vecteur cree par le fil conducteur
    mu0=4e-7*pi;
    X = x-xc;
    Y = y-yc;
    r = sqrt(X^2+Y^2);
    if (r<=rc) 
        az = -mu0*I/(4*pi)*r^2/rc^2;
    else
        az = -mu0*I/(2*pi)*(1/2+log(r/rc));
    end
end
```
{{% /expand%}}

2. En déduire celui crée par le conducteur précédent et son retour séparés d'une distance $d\_{if}$. 
{{% expand "Cliquer pour afficher un indice" %}}
On pourra penser à utiliser le **théorème de superposition**. 
{{% /expand%}}
{{% expand "Cliquer pour afficher la solution en MATLAB" %}}
```Matlab
close all; clear; clc

%%% ligne bifilaire
I = 1;        % courant (A)
rc = 1e-3;    % rayon conducteur (m)
dif = 1e-2;   % distance inter-fils
adom = 2*dif; % largeur domaine (m)

bfil1  = @(x,y) b_fil(x,y, dif/2,0, rc, I); 
azfil1 = @(x,y) a_fil(x,y, dif/2,0, rc, I);
bfil2  = @(x,y) b_fil(x,y,-dif/2,0, rc,-I); 
azfil2 = @(x,y) a_fil(x,y,-dif/2,0, rc,-I);

npoints = 100; x = linspace(-adom/2,adom/2,npoints); y = x; 
[X,Y] = meshgrid(x,y);
[B1X,B1Y] = arrayfun(bfil1,X,Y); [B2X,B2Y] = arrayfun(bfil2,X,Y);
BX = B1X + B2X; BY = B1Y + B2Y;
AZ1 = arrayfun(azfil1,X,Y); AZ2 = arrayfun(azfil2,X,Y);
AZ = AZ1 + AZ2;

figure(1)
nlignes = 25;
quiver(X,Y,BX,BY,5,'r')
axis equal; hold on;
contour(X,Y,AZ,nlignes,'LineWidth',2)

% dessin des conducteurs
nt = 60; theta = linspace(0,2*pi,nt); 
xd = dif/2+rc.*cos(theta); yd = rc.*sin(theta);
xg = -dif/2+rc.*cos(theta); yg = yd;
plot(xg,yg,'k','LineWidth',3)
plot(xd,yd,'k','LineWidth',3)

%#####################
%
%     fonctions
%
%#####################

function [bx,by] = b_fil(x,y,xc,yc,rc,I)
    % induction creee par le fil conducteur
    mu0=4e-7*pi;
    X = x-xc; Y = y-yc;
    r = sqrt(X^2+Y^2);
    if (r<=rc) 
        h_theta = I/(2*pi)*r/rc^2;
    else
        h_theta = I/(2*pi*r);
    end
    normb = mu0*h_theta;
    theta = atan2(Y,X);
    bx = -normb*sin(theta);
    by = normb*cos(theta);
end

function az = a_fil(x,y,xc,yc,rc,I)
    % potentiel vecteur cree par le fil conducteur
    mu0=4e-7*pi;
    X = x-xc;
    Y = y-yc;
    r = sqrt(X^2+Y^2);
    if (r<=rc) 
        az = -mu0*I/(4*pi)*r^2/rc^2;
    else
        az = -mu0*I/(2*pi)*(1/2+log(r/rc));
    end
end
```
{{% /expand%}}

3. En déduire finalement le champ total créé par la bobine et retrouver le tracé de la solution :
![Champ de la bobine rectangulaire](../../images/figures/bobine_rect.svg) 

{{% expand "Cliquer pour afficher la solution en MATLAB" %}}
```Matlab
close all; clear; clc

%%% bobine rectangulaire
I = 1;        % courant (A)
rc = 1e-3;    % rayon conducteur (m)
dif = 1e-2;   % distance inter-fils
nspires = 9;  % nombre de spires
dis = 3e-3;   % distance inter-spires
adom = max(2*dif,1.5*(nspires-1)*dis); % largeur domaine (m)

npoints = 100; x = linspace(-adom/2,adom/2,npoints); y = x;
[X,Y] = meshgrid(x,y);
BX = zeros(npoints); BY = zeros(npoints); AZ = zeros(npoints);

for k = 1:nspires
    bfil1  = @(x,y) b_fil(x,y, dif/2,-(nspires-1)*dis/2+(k-1)*dis, rc, I);
    azfil1 = @(x,y) a_fil(x,y, dif/2,-(nspires-1)*dis/2+(k-1)*dis, rc, I);
    bfil2  = @(x,y) b_fil(x,y,-dif/2,-(nspires-1)*dis/2+(k-1)*dis, rc,-I);
    azfil2 = @(x,y) a_fil(x,y,-dif/2,-(nspires-1)*dis/2+(k-1)*dis, rc,-I);
    [B1X,B1Y] = arrayfun(bfil1,X,Y); [B2X,B2Y] = arrayfun(bfil2,X,Y);
    BX = BX + B1X + B2X; BY = BY + B1Y + B2Y;
    AZ1 = arrayfun(azfil1,X,Y); AZ2 = arrayfun(azfil2,X,Y);
    AZ = AZ + AZ1 + AZ2;
end

figure(1)
nlignes = 30;
quiver(X,Y,BX,BY,5,'r')
axis equal; hold on;
contour(X,Y,AZ,nlignes,'LineWidth',2)
% dessin des conducteurs
nt = 60; theta = linspace(0,2*pi,nt); 
xt = rc.*cos(theta); yt = rc.*sin(theta);
xg = zeros(nspires,nt); yg = zeros(nspires,nt);
xd = zeros(nspires,nt); yd = zeros(nspires,nt);
for k = 1:nspires
    xg(k,:) = -dif/2+xt; xd(k,:) = dif/2+xt;
    yg(k,:) = -(nspires-1)*dis/2+(k-1)*dis+yt; yd(k,:) = yg(k,:);
    plot(xg(k,:),yg(k,:),'k','LineWidth',2)
    plot(xd(k,:),yd(k,:),'k','LineWidth',2)
end

%%%###################
%
%     fonctions
%
%#####################

function [bx,by] = b_fil(x,y,xc,yc,rc,I)
    % induction creee par le fil conducteur
    mu0=4e-7*pi;
    X = x-xc; Y = y-yc;
    r = sqrt(X^2+Y^2);
    if (r<=rc)
        h_theta = I/(2*pi)*r/rc^2;
    else
        h_theta = I/(2*pi*r);
    end
    normb = mu0*h_theta;
    theta = atan2(Y,X);
    bx = -normb*sin(theta);
    by = normb*cos(theta);
end

function az = a_fil(x,y,xc,yc,rc,I)
    % potentiel vecteur cree par le fil conducteur
    mu0=4e-7*pi;
    X = x-xc;
    Y = y-yc;
    r = sqrt(X^2+Y^2);
    if (r<=rc)
        az = -mu0*I/(4*pi)*r^2/rc^2;
    else
        az = -mu0*I/(2*pi)*(1/2+log(r/rc));
    end
end
```
{{% /expand%}}

---


## Ex.4. : Cylindre plongé dans un champ uniforme

On considère une région de l'espace où règne un champ d'induction uniforme (imposé par une source extérieure) de la forme : ${\bf b} = B\_{0}\\,{\bf u\_x}$.  
On place à l'intérieur de cette zone un cylindre de rayon $R$ constitué d'un matériau de perméabilité relative $\mu\_r$ constante. 

1. Caluler, par séparation des variables, le potentiel vecteur magnétique ${\bf a}$ en tout point du domaine. 

{{% expand "Cliquer pour afficher un indice" %}}
On pensera à utiliser les coordonnées cylindriques et donc calculer le potentiel vecteur magnétique ${\bf a} = a\_{z}(r,\theta)\\,{\bf u\_z}$.  
{{% /expand%}}

2. En déduire le tracé des lignes de champ d'induction correspondantes et observer les différents cas possibles en fonction du type du matériau. C'est-à-dire : 
![Cylindre dans champ uniforme](../../images/figures/cylindre.svg "Déformation des lignes de champ due au cylindre")
Utiliser le langage de votre choix : MATLAB (ou GNU/Octave), Python, Julia, etc...

{{% expand "Cliquer pour afficher une solution" %}}
Un exemple de calcul en MATLAB est donné ci-dessous :
```Matlab
close all; clear; clc

% cylindre dans champ uniforme
R = 2e-2;    % rayon du cylindre
adom = 6*R;  % largeur du domaine
B0 = 1;      
mur = 1e3;   

% evaluation sur grille
a = @(x,y) az(x,y,R,mur,B0); 
npoints = 100; x = linspace(-adom/2,adom/2,npoints); y = x;
[X,Y] = meshgrid(x,y);
AZ = arrayfun(a,X,Y);

% tracé
nlignes = 30;
contour(X,Y,AZ,nlignes,'LineWidth',1)
axis equal; hold on;
nc = 60; theta = linspace(0,2*pi,nc);     % contour du cylindre
plot(R*cos(theta),R*sin(theta),'k','LineWidth',2)

% fonction calcul du potentiel vecteur
function a = az(x,y,R,mur,B0)
	r = sqrt(x^2+y^2);
	theta = atan2(y,x);
	if (r <= R)
	    a = 2*mur/(mur+1)*B0*r*sin(theta);
	else
	    a = B0*(r+(mur-1)/(mur+1)*R^2/r)*sin(theta);
	end
end
```
{{% /expand%}}


--- 


## Ex. 5. : Câble coaxial  

On considère un câble coaxial portant un courant $I$ tel que représenté sur la figure ci-dessous.

{{< figure src="../../images/figures/coax_schem.svg" title="Représentation schématique du câble coaxial considéré">}}

1. Après avoir calculé le rayon intérieur du coax permettant d'assurer la même densité de courant dans les conducteurs aller et retour, calculer le champ magnétique en tout point de l'espace.
2. En déduire l'énergie magnétique (par unité de longueur) et la valeur de l'inductance linéique du câble.

{{% expand "Cliquer pour afficher un indice" %}}
On pourra penser à utiliser le **théorème d'Ampère** pour calculer le champ.  
{{% /expand%}}


{{% expand "Cliquer pour afficher un début de solution" %}}
![Allure du champ du coax](../../images/figures/coax.svg "Allure du champ du coax") 
Le code MATLAB permettant de faire le calcul et le tracé est donné ci-dessous à titre indicatif :   
```Matlab
close all; clear; clc

% rayons du cable coaxial :
Ri = 1e-3;
R0 = 2e-3;
Re = sqrt(Ri^2+R0^2); % pour egalite des surfaces
Rdom = 1.5*Re;          % fin du trace

I = 15; % courant (A)

% fonction pour calculer le champ
h_theta = @(r) I/(2*pi)*((r<=Ri)*r/Ri^2+(Ri<r)*(r<=R0)/r...
     +(R0<r)*(r<=Re)*(1 -(r^2-R0^2)/(Re^2-R0^2))/r);

npoints = 1000; rt = linspace(0,Rdom,npoints);
ht = arrayfun(h_theta,rt); % evaluations 
% trace du resultat
plot(rt,ht,LineWidth=2)
title("h_\theta en fonction de la distance au centre du coax")
grid on; xlabel("r (en mm)"); ylabel("h_\theta (en A/m)")
xticks([0 Ri R0 Re]) ; xticklabels(["0", "R_i", "R_0", "R_e"])
yticks([0 I/2/pi/R0 I/2/pi/Ri]); 
yticklabels(["0", "I/(2\pi R_0)", "I/(2\pi R_1)"])
```
{{% /expand%}}


---


## Ex. 6 : Transformateur élémentaire

On considère le transformateur élémentaire donné par la figure ci-dessous. Le primaire (en bleu) est constitué de $N_1$ spires, et le secondaire (en rouge) en comporte $N_2$. 

{{< figure src="../../images/figures/transfo.svg" title="Représentation schématique du transformateur considéré">}}

1. Calculer les inductances propres et mutuelle dans le cas où la loi de comportement du matériau magnétique est linéaire (de perméabilité relative $\mu_r$).
2. Reprendre la question précédente dans le cas d'une loi de comportement non-linéaire. Choisir des valeurs réalistes pour les paramètres afin de tracer l'évolution des inductances en fonction des courants. On résoudra avec un petit programme au choix en : MATLAB (ou GNU/Octave), ou Python, ou Julia, ou autre...    
Je vous donne les vecteurs associés à la courbe $b(h)$ du matériau (XC10) et un exemple de son utilisation en MATLAB :   
```Matlab
% Valeurs correspondant au XC10 :
H = [0.000000, 79.577472, 100.182101, 126.121793, 158.777930, 199.889571, 251.646061, ...
	316.803620, 398.832128, 502.099901, 632.106325, 795.774715, 1001.821011, ...
	1261.217929, 1587.779301, 1998.895710, 2516.460605, 3168.036204, 3988.321282, ...
	5020.999013, 6321.063250, 7957.747155, 10018.210114, 12612.179293, 15877.793010, ...
	19988.957103, 25164.606052, 31680.362037, 39883.212823, 50209.990127, 63210.632497, ...
	79577.471546, 100182.101136, 126121.792926, 158777.930096, 199889.571030, ...
	251646.060522, 316803.620370];

B = [0.000000, 0.211862, 0.265665, 0.332377, 0.414377, 0.513811, 0.631899, 0.767784, ...
	0.917018, 1.070353, 1.214255, 1.334637, 1.422981, 1.480634, 1.517214, 1.544515, ...
	1.571296, 1.602049, 1.638404, 1.680490, 1.727311, 1.776659, 1.825401, 1.870557, ...
	1.910809, 1.947222, 1.982328, 2.018252, 2.055398, 2.092545, 2.128095, 2.161612, ...
	2.194644, 2.230339, 2.272386, 2.324282, 2.389356, 2.471238];

% calcul de B(H)
function Bres = BdeH(B,H,valH)
	if ( valH < H(length(H)) )
		Bres = interp1(H,B,valH);
	else
		Bres = B(length(B))+mu0*(valH-H(length(H)));
	end
end
```

{{% expand "Cliquer pour afficher un indice" %}}
On pourra encore penser à utiliser le théorème d'Ampère pour calculer le champ. 
{{% /expand%}}

{{% expand "Cliquer pour afficher la solution" %}}
![Inductance du primaire en fonction du courant](../../images/figures/L1deI.svg "Inductance du primaire en fonction du courant")
Le code MATLAB permettant de faire le calcul et le tracé est donné ci-dessous :   
```Matlab
clear; clc;

a = 3e-2; 
b = 5e-2;
c = 10e-2;
N1 = 100;
Lz = 15e-2;
Lf = 2*(2*a+b+c);

% Valeurs correspondant au XC10 :
H = [0.000000, 79.577472, 100.182101, 126.121793, 158.777930, 199.889571, 251.646061, ...
	316.803620, 398.832128, 502.099901, 632.106325, 795.774715, 1001.821011, ...
	1261.217929, 1587.779301, 1998.895710, 2516.460605, 3168.036204, 3988.321282, ...
	5020.999013, 6321.063250, 7957.747155, 10018.210114, 12612.179293, 15877.793010, ...
	19988.957103, 25164.606052, 31680.362037, 39883.212823, 50209.990127, 63210.632497, ...
	79577.471546, 100182.101136, 126121.792926, 158777.930096, 199889.571030, ...
	251646.060522, 316803.620370];

B = [0.000000, 0.211862, 0.265665, 0.332377, 0.414377, 0.513811, 0.631899, 0.767784, ...
	0.917018, 1.070353, 1.214255, 1.334637, 1.422981, 1.480634, 1.517214, 1.544515, ...
	1.571296, 1.602049, 1.638404, 1.680490, 1.727311, 1.776659, 1.825401, 1.870557, ...
	1.910809, 1.947222, 1.982328, 2.018252, 2.055398, 2.092545, 2.128095, 2.161612, ...
	2.194644, 2.230339, 2.272386, 2.324282, 2.389356, 2.471238];

h1 = @(I) N1*I/Lf;
phi1 = @(I) N1*BdeH(B,H,h1(I))*2*a*Lz;
L1 = @(I) phi1(I)/I;

npoints = 500; Imax = 10;
I = linspace(0,Imax,npoints);
L = arrayfun(L1,I);
plot(I,L,"LineWidth",3)
xlabel("Courant (en A)"); ylabel("Inductance (en H)")
title("Inductance primaire en fonction du courant")
grid; axis([-inf inf 0 ceil(10*max(L))/10])

% calcul de B(H)
function Bres = BdeH(B,H,valH)
	mu0 = 4e-7*pi;
	if ( valH < H(length(H)) )
		Bres = interp1(H,B,valH);
	else
		Bres = B(length(B))+mu0*(valH-H(length(H)));
	end
end
```

{{% /expand%}}


---

## Ex. 7. : Électroaimant

On considère l'électroaimant représenté sur la figure ci-dessous : 

![Électroaimant](../../images/figures/ventouse.svg "Schéma de l'électroaimant considéré")

1. Considérons tout d'abord que le circuit magnétique est infiniment perméable (hypothèse du $\mu\_{\infty}$). Calculer la force $F$ s'exerçant sur la partie mobile (plaque du bas) par les dérivées de l'énergie et la coénergie, et mettre en évidence la différence de signe entre les deux expressions. Retrouver ensuite la valeur de la force par le tenseur de Maxwell.

2. Recalculer la force par le tenseur mais dans le cas où le circuit magnétique a une loi de comportement linéaire (perméabilité $\mu_r$). En déduire l'expression de la force de collage (à entrefer $e$ nul). 

3. En utilisant les valeurs de paramètres et de courbes $b(h)$ données ci-dessous, superposer les tracés de la force en fonction du courant ($F(I_c)$) dans les 2 cas : linéaire et non-linéaire.   

```Matlab
mu0 = 4e-7*pi;  % H/m
aE = 1e-2;      % m
bE = 1e-2;
hE = 2e-2;
ent = 0.5e-3;
Ep = 1.e-2;
Lz = 20e-2;
N = 250;

% Loi de comportement des materiaux
% pour le E (M530) :
HE = [0.000000,  19.965330, 29.906288, 36.398771, 41.371669, 45.590262, 49.424859, ...
    53.082280, 56.692664, 60.347374, 64.117637, 68.064755, 72.246371, 76.720886, ...
    81.551123, 86.807959, 92.574503, 98.951520, 106.065047, 114.077777, 123.206911, ...
    133.753385, 146.151738, 161.058668, 179.516634, 203.267945, 235.379748, ...
    281.524948, 352.648412, 470.426179, 677.451541, 1051.068036, 1703.275165, ...
    2726.517959, 4137.981052, 5832.619704, 7939.552940, 10565.294335, 13843.912965, ...
    17970.359698, 23423.776432, 32234.325960, 51366.778967, 84577.843501, ...
    121162.493322, 160127.812767, 202470.282245];
BE = [0.00, 0.05, 0.10, 0.15, 0.20, 0.25, 0.30, 0.35, 0.40, 0.45, 0.50, 0.55, ...
    0.60, 0.65, 0.70, 0.75, 0.80, 0.85, 0.90, 0.95, 1.00, 1.05, 1.10, 1.15, 1.20, ...
    1.25, 1.30, 1.35, 1.40, 1.45, 1.50, 1.55, 1.60, 1.65, 1.70, 1.75, 1.80, 1.85, ...
    1.90, 1.95, 2.00, 2.05, 2.10, 2.15, 2.20, 2.25, 2.30];

% pour la plaque (XC10) :
Hp = [0.000000, 79.577472, 100.182101, 126.121793, 158.777930, 199.889571, 251.646061, ...
    316.803620, 398.832128, 502.099901, 632.106325, 795.774715, 1001.821011, ...
    1261.217929, 1587.779301, 1998.895710, 2516.460605, 3168.036204, 3988.321282, ...
    5020.999013, 6321.063250, 7957.747155, 10018.210114, 12612.179293, 15877.793010, ...
    19988.957103, 25164.606052, 31680.362037, 39883.212823, 50209.990127, 63210.632497, ...
    79577.471546, 100182.101136, 126121.792926, 158777.930096, 199889.571030, ...
    251646.060522, 316803.620370];
Bp = [0.000000, 0.211862, 0.265665, 0.332377, 0.414377, 0.513811, 0.631899, 0.767784, ...
    0.917018, 1.070353, 1.214255, 1.334637, 1.422981, 1.480634, 1.517214, 1.544515, ...
    1.571296, 1.602049, 1.638404, 1.680490, 1.727311, 1.776659, 1.825401, 1.870557, ...
    1.910809, 1.947222, 1.982328, 2.018252, 2.055398, 2.092545, 2.128095, 2.161612, ...
    2.194644, 2.230339, 2.272386, 2.324282, 2.389356, 2.471238];

% calcul de H(B)
function Hres = HdeB(B,H,valB)
	mu0 = 4e-7*pi;
	if ( valB < B(length(B)) )
		Hres = interp1(B,H,valB);
	else
		Hres = H(length(H))+1/mu0*(valB-B(length(B)));
	end
end
```

{{% notice note %}}
Cet exercice est adapté de la [**ventouse magnétique de fermeture de porte**](https://cours.jufont.net/ensem/tp-femm/ventouse.html) des TP FEMM de l'EC S8-B11-EC2.
{{% /notice %}}

{{% expand "Cliquer pour afficher la solution" %}}
![Force de l'électroaimant](../../images/figures/force_ventouse.svg "Force développée par l'électroaimant considéré")
Le code MATLAB pour faire le calcul :
```Matlab
clear; clc

mu0 = 4e-7*pi;   % H/m
aE = 1e-2;      % m
bE = 1e-2;
hE = 2e-2;
ent = 0.5e-3;
Ep = 1.e-2;
Lz = 20e-2;
N = 250;

% Loi de comportement des materiaux
%--------------------------------------
% pour le E (M530) :
HE = [0.000000,  19.965330, 29.906288, 36.398771, 41.371669, 45.590262, 49.424859, ...
    53.082280, 56.692664, 60.347374, 64.117637, 68.064755, 72.246371, 76.720886, ...
    81.551123, 86.807959, 92.574503, 98.951520, 106.065047, 114.077777, 123.206911, ...
    133.753385, 146.151738, 161.058668, 179.516634, 203.267945, 235.379748, ...
    281.524948, 352.648412, 470.426179, 677.451541, 1051.068036, 1703.275165, ...
    2726.517959, 4137.981052, 5832.619704, 7939.552940, 10565.294335, 13843.912965, ...
    17970.359698, 23423.776432, 32234.325960, 51366.778967, 84577.843501, ...
    121162.493322, 160127.812767, 202470.282245];
BE = [0.00, 0.05, 0.10, 0.15, 0.20, 0.25, 0.30, 0.35, 0.40, 0.45, 0.50, 0.55, ...
    0.60, 0.65, 0.70, 0.75, 0.80, 0.85, 0.90, 0.95, 1.00, 1.05, 1.10, 1.15, 1.20, ...
    1.25, 1.30, 1.35, 1.40, 1.45, 1.50, 1.55, 1.60, 1.65, 1.70, 1.75, 1.80, 1.85, ...
    1.90, 1.95, 2.00, 2.05, 2.10, 2.15, 2.20, 2.25, 2.30];
% pour la plaque (XC10) :
Hp = [0.000000, 79.577472, 100.182101, 126.121793, 158.777930, 199.889571, 251.646061, ...
    316.803620, 398.832128, 502.099901, 632.106325, 795.774715, 1001.821011, ...
    1261.217929, 1587.779301, 1998.895710, 2516.460605, 3168.036204, 3988.321282, ...
    5020.999013, 6321.063250, 7957.747155, 10018.210114, 12612.179293, 15877.793010, ...
    19988.957103, 25164.606052, 31680.362037, 39883.212823, 50209.990127, 63210.632497, ...
    79577.471546, 100182.101136, 126121.792926, 158777.930096, 199889.571030, ...
    251646.060522, 316803.620370];
Bp = [0.000000, 0.211862, 0.265665, 0.332377, 0.414377, 0.513811, 0.631899, 0.767784, ...
    0.917018, 1.070353, 1.214255, 1.334637, 1.422981, 1.480634, 1.517214, 1.544515, ...
    1.571296, 1.602049, 1.638404, 1.680490, 1.727311, 1.776659, 1.825401, 1.870557, ...
    1.910809, 1.947222, 1.982328, 2.018252, 2.055398, 2.092545, 2.128095, 2.161612, ...
    2.194644, 2.230339, 2.272386, 2.324282, 2.389356, 2.471238];

% Longueurs du contour
lE = 2*hE + 2*aE + bE;   % dans le E
lp = bE + Ep + aE;       % dans la plaque

% en lineaire
npoints = 1000; Imax = 10;
I = linspace(0,Imax,npoints);
murE = (BE(3)-BE(2))/(HE(3)-HE(2))/mu0;  % db/dh
murp = (Bp(3)-Bp(2))/(Hp(3)-Hp(2))/mu0;

he = N*I/(2*ent+lE/murE+lp/murp);
ForceLin = 2*mu0*aE*Lz*he.^2;

% en non-lineaire
ThmAmpere = @(b,I) HdeB(BE,HE,b)*lE + 2*ent*b/mu0 + HdeB(Bp,Hp,b*aE/Ep)*lp - N*I;
options = optimoptions("fsolve");
options.Display = 'off';
be = @(I) fsolve(@(b) ThmAmpere(b,I),mu0*N*I/(2*ent+lE/murE+lp/murp),options);
ForceNL = @(I) 2/mu0*aE*Lz*be(I)^2;
ForceNonLin = arrayfun(ForceNL,I);

% tracé
plot(I,ForceLin,I,ForceNonLin,'LineWidth',2)
grid; xlabel('Courant (en A)'); ylabel('Force (en N)')
title ('Force en fonction du courant')
legend(' En linéaire',' En non-linéaire',"Location","northwest")


% calcul de H(B)
function Hres = HdeB(B,H,valB)
    mu0 = 4e-7*pi;
	if ( valB < B(length(B)) )
		Hres = interp1(B,H,valB);
	else
		Hres = H(length(H))+1/mu0*(valB-B(length(B)));
	end
end
```
{{% /expand%}}

--- 

## Ex. 8. : Barre de machine asynchrone

Le but de l'exercice est de calculer l'inductance de fuite et la résistance d'une barre de machine asynchrone à cage en fonction de la fréquence du courant rotorique. Lorsque le rayon d'alésage de la machine est assez grand, le problème peut se ramener à un problème 2D cartésien tel que représenté par la figure :

![Barre de MAS](../../images/figures/barreMAS.svg)

#### Cas statique :

Le courant I circulant dans la barre est supposé continu ($I = I_0$). Après avoir précisé vos hypothèses :
1. Que vaut la densité de courant dans le cuivre $j$ ? En déduire la valeur des pertes Joule et de la résistance de la barre $R_0$.
2. Tracer l'allure des lignes de champ dans cette portion de dispositif.
3. En utilisant le théorème d’Ampère, calculer la valeur du champ magnétique $h$ dans l'encoche, c'est-à-dire : dans la zone d'air entre le cuivre et l'entrefer, et dans la barre de cuivre.
4. Tracer $h_x(y)$ pour $y \in \[0 ; h 1 + h 2 \]$.
5. En déduire la valeur de l'énergie magnétique $W_e$ stockée dans l'encoche, et l'inductance de fuite $L\_{f_0}$ définie par : $$W_e = \frac{1}{2}\\,L\_{f_0}\\,I^2$$

#### Cas harmonique :

Le courant I est maintenant supposé sinusoïdal : $I(t) = I\_{\text{eff}}\\,\sqrt{2}\\,\sin(\omega\\,t)$.

1. Dans quelle zone de l'encoche peut-on encore utiliser le théorème d'Ampère ?
2. Quelle est l'équation vérifiée par $h$ dans le cuivre ?
3. Résoudre cette équation grâce à un passage en complexes.
4. En déduire la valeur de $W_e$, puis de l'inductance de fuite $L_f$ en fonction de la fréquence.
5. À partir des questions précédentes, déterminer la valeur de la densité de courant complexe dans le cuivre. En déduire la valeur des pertes Joule et de la résistance $R$ de la barre en fonction de la fréquence.
6. Vérifier les cas limites : $\lim\limits\_{\omega \to 0} L_f (\omega) = L\_{f_0}$ et $\lim\limits_{\omega\to 0} R(\omega) = R_0$.

{{< rawhtml >}}
<br>
{{< /rawhtml >}}


#### Tracé des résultats :

{{< figure src="../../images/figures/res_encoche.svg" title="Densité volumique de courant dans l'encoche à 50 Hz">}}

{{< figure src="../../images/figures/Lf_R_def.svg" title="Évolution de la valeur de l'inductance de fuite et de la résistance de la barre en fonction de la fréquence">}}


{{%attachments title="Correction" style="grey" pattern="corrige*.*(pdf)"/%}}



---

## Ex. 9. : Résistance d'une barre cylindrique alimentée en alternatif

La barre de cuivre de l'exercice [**Ex.1**](#exo1) est désormais alimentée en courant alternatif.  
Calculer la densité de courant lorsque la barre est parcourue par un courant $I(t) = \sqrt{2}\\,I\_{\text{eff}}\\,\cos(\omega\\,t)$.

On utilise la transformation en complexes pour résoudre l'équation locale satisfaite par $\underline{\bf j}$ :

1. Après avoir constaté que la densité de courant complexe est de la forme $\underline{\bf j} = \underline{j\_z} (r)\\,{\bf u\_z}$, donner l'équation différentielle ordinaire satisfaite par $\underline{j\_z}$. 
2. Résoudre cette équation en cherchant une solution sous la forme d'une série entière.  
On pensera à introduire l'épaisseur de peau $\delta = \sqrt{\frac{2}{\sigma \mu\_0 \omega}}$
3. Exprimer la formule générale de cette solution de façon plus concise en utlisant les [**fonctions de Bessel de première espèce**](../../formulaire/#bessel) $J\_n$. 
4. Grâce à une condition de passage judicieusement choisie, retrouver la solution du problème :
$$ \displaystyle\underline{j\_z}(r) = \frac{\sqrt{-j}\\,I\_{\text{eff}}}{\sqrt{2}\\,\pi R\\,\delta} \frac{J\_0(\sqrt{-j}\\,\frac{\sqrt{2}\\,r}{\delta})}{J\_1(\sqrt{-j}\\,\frac{\sqrt{2}\\,R}{\delta})}$$
5. En déduire l'expression de la densité volumique de puissance, puis les pertes Joules totales dans la barre, et donc sa résistance. 
6. Tracer son évolution avec un logiciel de calcul numérique et discuter des cas limites : $\omega \rightarrow 0$ et $\omega \rightarrow \infty$. 

#### Tracé des résultats :

{{< figure src="../../images/figures/pjdef.png" title="Densité volumique de pertes Joule dans la barre pour trois fréquences (0 Hz / 100 Hz / 10 kHz)">}}

{{< figure src="../../images/figures/Rdef.svg" title="Évolution de la valeur de la résistance en fonction de la fréquence">}}

{{% expand "Cliquer pour afficher le code MATLAB permettant de faire ces tracés" %}}
```Matlab
close all; clear; clc;

mu0 = 4e-7*pi; R = 1e-2; sigma = 56e6; I = 10; L = 1; j = 1i;

npoints = 1000; r = linspace(0,R,npoints); theta = linspace(0,2*pi,npoints);
[RR,THETA] = meshgrid(r,theta); X = RR.*cos(THETA); Y = RR.*sin(THETA);

figure(1)
vf = [1e-9,100,10e3]; tf = ["f = 0 Hz","f = 100 Hz","f = 10 kHz"];
for k = 1:3
    subplot(1,3,k)
    f = vf(k); w = 2*pi*f; delta = sqrt(2/(sigma*mu0*w));
    jz = sqrt(-j)*I/(sqrt(2)*pi*R*delta*besselj(1,sqrt(-j*2)*R/delta)) ...
        *besselj(0,sqrt(-j*2)*r/delta);
    pj = real(1/sigma*jz.*conj(jz));
    PJ = repmat(pj,npoints,1);
    sl = surface(X,Y,PJ);
    sl.EdgeColor='none'; axis equal; axis([-R R -R R]); 
    xticks([]); yticks([]); colorbar; colormap jet; title(tf(k))
end

figure(2)
dr = R/(npoints-1);
nf = 10000; f_fin = 10e4; valf = linspace(1e-6,f_fin,nf); Res = zeros(1,nf);
for k = 1:nf
    w = 2*pi*valf(k);
    delta = sqrt(2/(sigma*mu0*w));
    jz = sqrt(-j)*I/(sqrt(2)*pi*R*delta*besselj(1,sqrt(-j*2)*R/delta))... 
        *besselj(0,sqrt(-j*2)*r/delta);
    pj = real(1/sigma*jz.*conj(jz));
    pjr = pj.*r;
    Pj = pi*sum(pjr(2:npoints)+pjr(1:(npoints-1)))*dr*L;
    Res(k) = Pj/I^2;
end
subplot(1,2,1)
R0 = 1/sigma*L/(pi*R^2); f = linspace(0.8*f_fin,f_fin,0.2*nf);
delta = sqrt(1./(sigma*mu0*pi*f)); Rinf = 1/sigma*L./(2*pi*delta*R);
plot([0 0.1*f_fin],1e3*[R0 R0],'--b',LineWidth=2); hold on;
plot(f,1e3*Rinf,'--k',LineWidth=2) 
plot(valf,1e3*Res,'r',LineWidth=2)
axis([0 f_fin 0 inf]); grid on;
title('Résistance en fonction de la fréquence','FontSize',16)
xlabel('f (en Hz)','FontSize',14); ylabel('R (en m\Omega)','FontSize',14)
legend([" R_0"," R_\infty(f)"," R(f)"],FontSize=14,Location="northwest")
subplot(1,2,2)
plot([0 100],1e3*[R0 R0],'--b',LineWidth=2); hold on;
plot(valf,1e3*Res,'r',LineWidth=2)
axis([0 500 floor(1e5*R0)/1e2 2e3*R0]); grid on; 
title("Zoom vers l'origine",'FontSize',14); 
xlabel('f (en Hz)','FontSize',14); ylabel('R (en m\Omega)','FontSize',16)
```
{{% /expand%}}

{{%attachments title="Cet exercice est adapté d'un ancien examen :-)" style="grey" pattern="exam*.*(pdf)"/%}}


--- 

## Ex. 10. : Chauffage par induction d'une plaque d'acier

On considère une plaque d'acier (de perméabilité $\mu$ et de conductivité $\sigma$) de longueur $L_z$ et de largeur $l_y$ très grandes devant son épaisseur $2\\,e$. Cette plaque est placée à l'intérieur d'un inducteur correspondant à un solénoïde de longueur $L$ à $N$ spires jointives de forme rectangulaire.  
Celui-ci est parcouru par un courant $I(t)$ imposé. Une représentation schématique du dispositif et le repère associé sont donnés par la figure ci-dessous :

{{< figure src="../../images/figures/schema_plaque_induction.svg" title=" Représentation schématique du problème">}}

1. Dans un premier temps, on considère uniquement l'inducteur.  
En précisant vos hypothèses, et en utilisant le théorème d'Ampère sur 3 contours judicieusement choisis, montrez que le champ
magnétique à l'intérieur du solénoïde est uniforme et s'écrit : $ {\bf h_s} = n\\,I(t)\\,{\bf u_z} $.   
On explicitera la valeur de $n$ en fonction de $N$ et $L$.

2. Le courant d'alimentation est : $ I(t) = I_{\text{eff}} \sqrt{2}\\,\cos(\omega\\,t) $. Donner la forme complexe du courant $\underline{I}$, ainsi que du champ précédent $\underline{h_s}$. 

3. Désormais, on insère la plaque dans l'inducteur. Donner, en le justifiant, l'équation générale de diffusion à laquelle obéit le
champ magnétique à l'intérieur de celle-ci ( $x \in [−e; e]$).

4. À partir de l'équation précédente et de la question 2, donner la forme complexe du système permettant de calculer le champ complexe $\underline{\bf h}(x)$ dans la plaque. Soit : une équation différentielle ordinaire d'ordre 2 à coefficients constants complexes et 2 conditions aux limites.

5. Résoudre ce système (on fera intervenir l'épaisseur de peau $\delta$).

6. En déduire l'expression complexe de la densité de courant dans la plaque, puis celle de la densité volumique de puissance moyenne
$p$ injectée dans la plaque par l'inducteur, et donc de la puissance moyenne totale $P$ injectée dans la plaque.


#### Tracé des résultats :

{{< figure src="../../images/figures/plaque_induction.gif" title="Représentation du champ magnétique et de la densité de puissance dans la plaque">}}

{{< rawhtml >}}
<br>
{{< /rawhtml >}}


---

{{< rawhtml >}}
<br>
<br>
{{< /rawhtml >}}

{{% notice warning %}}
$$ \text{{\LARGE That's all Folks!}} $$
{{% /notice %}}


