---
title: Magnétostatique
weight: 30
#pre: "<b>3. </b>"
chapter: false
math: true
---


La **magnétostatique** (en anglais *magnetostatics*) correspond au calcul de la distribution du champ ou de l'induction magnétiques produit par des courants continus ou des aimants.

Considérons le domaine $\Omega$ de $\mathbb{R}^3$ constitué de plusieurs sous-domaines schématisé par la figure :
![Domaine magnétostatique](../../images/figures/magnetostat.svg "Domaine considéré dans le cadre de la magnétostaique")
* $\Omega_m$ correspondant à des matériaux magnétiques ;
* $\Omega_c$ correspondant à des conducteurs électriques parcourus par une densité de courant imposée par une source extérieure ${\bf j_s}$ ;
* $\Omega_a$ correspondant à des aimants permanents d'induction rémanente ${\bf b_r}$ ;
* une zone d'air entourant ses différents sous-domaines.

Et sa frontière $\Gamma (=\partial\Omega)$ est divisée en deux morceaux $\Gamma_d$ et $\Gamma_n$.  



Les relations régissant la magnétostatique sont : 
- Les équations de Maxwell en statique suivantes : $$\left\\{\begin{aligned}\text{div}\\,{\bf b} &= 0\\\\{\bf rot}\\,{\bf h} &= {\bf j_s}~\text{dans }  \Omega_c, \text{ et } {\bf 0} \text{ ailleurs}\end{aligned}\right.$$
- Les lois de comportements magnétiques : $$\left\\{\begin{aligned}{\bf b} &= \mu\_0\\,{\bf h}&\text{dans l'air et }\Omega_c\\\\{\bf b} &= \mu\\,{\bf h} &\text{dans~}\Omega\_m\\\\{\bf b} &= \mu_0\mu\_{ra}\\, {\bf h}+{\bf b_r} &\text{dans~}\Omega\_a\end{aligned}\right.$$
- Les contions aux limites, par exemple :
	* continuité de la composante normale de l'induction : ${\bf n}\cdot{\bf b} = 0$ sur $\Gamma_d$ ;
	* continuité de la composante tangentielle du champ : ${\bf n}\wedge{\bf h} = {\bf 0}$ sur $\Gamma_n$. 


---

## Formulation en potentiel vecteur magnétique

### Formulation forte

${\bf b}$ étant à divergence nulle, nous avons vu dans le [premier chapitre](../../electromag/potentiels/), qu'il était possible de définir un potentiel vecteur magnétique ${\bf a}$ tel que : 
$${\bf b} = {\bf rot}\\,{\bf a}$$

En lui associant les lois de comportement et en reportant dans l'équation de Maxwell-Ampère, on obtient : 
$$\left\\{\begin{aligned} {\bf rot}\left(\frac{1}{\mu_0}{\bf rot}\\,{\bf a}\right) - {\bf j_s} &= 0 ~ ,\text{ dans }\Omega_c\\\\ {\bf rot}\left(\frac{1}{\mu\_{ra}\mu_0}\left({\bf rot}\\,{\bf a}-{\bf b_r}\right)\right) &= 0~ ,\text{ dans }\Omega_a\\\\ {\bf rot}\left(\frac{1}{\mu}{\bf rot}\\,{\bf a}\right) &= 0 ~ ,\text{ ailleurs }\end{aligned}\right.$$ 

Et nos conditions aux limites peuvent se traduire par :
$$\left\\{\begin{aligned} \left.{\bf a}\wedge{\bf n}\right|\_{\Gamma_d} &= {\bf 0}\\\\ \left.{\bf rot}\\,{\bf a}\wedge{\bf n}\right|\_{\Gamma_n} &= {\bf 0} \end{aligned}\right.$$ 


### Formulation faible

En appliquant le principe détaillé dans le deuxième chapitre sur la [formulation en **rot-rot**](../../principe/continu/#formulation-variationnelle-1), on peut déduire la formulation faible de notre problème : 

Trouver ${\bf a} \in \textbf{H}\_{0}({\bf rot},\Omega) = \\{ {\bf a} \in \textbf{H}({\bf rot},\Omega) : {\bf a}\wedge{\bf n}\|\_{\Gamma_{d}} = 0\\}$, tel que : 

$$\forall {\bf a'} \in \textbf{H}\_{0}({\bf rot},\Omega),~~ \left(\mu^{-1}\\,{\bf rot}\\,{\bf a}\\,,\\,{\bf rot}\\,{\bf a'}\right)\_{\Omega} + \left(\mu^{-1}\\,{\bf b_r}\\,,\\,{\bf rot}\\,{\bf a'}\right)\_{\Omega_a} + \left( -{\bf j_s} \\,,\\, {\bf a'}\right)\_{\Omega_c}= 0$$

{{% notice warning %}}
Rappelons ici que la formulation ci-dessus ne conduit pas à une solution unique comme vu dans les chapitres précédents, il nous faudra rajouter une condition de jauge sur ${\bf a}$ pour pouvoir le calculer en 3D (jauge de Coulomb ou jauge d'arbre).
{{% /notice %}}


---

### Formulation en potentiel scalaire magnétique

### Formulation forte

Dans le cas particulier d'un problème sans densité de courant source $({\bf j_s} = {\bf 0})$, on a : ${\bf rot}\\,{\bf h} = {\bf 0}$ dans tout le domaine. 

On peut alors définir un potentiel scalaire magnétique $\phi$ tel que : $${\bf h} = -{\bf grad}\\,\phi$$

En lui associant les lois de comportement et en reportant dans l'équation de Maxwell-Thomson, on obtient : 

$$\left\\{\begin{aligned}\text{div}\left(-\mu\\,{\bf grad}\\,\phi\right) &= 0~,  &\text{dans}~ \Omega\setminus\Omega\_a\\\\ \text{div}\left(-\mu\\,{\bf grad}\\,\phi + {\bf b_r}\right) &= 0~,  &\text{dans}~ \Omega_a \end{aligned}\right.$$

Et nos conditions aux limites peuvent se traduire par :
$$\left\\{\begin{aligned} \left.\phi\right|\_{\Gamma_n} &= {\bf 0}\\\\ \left.{\bf grad}\\,\phi\cdot{\bf n}\right|\_{\Gamma_d} &= {\bf 0} \end{aligned}\right.$$ 

### Formulation faible

En procédant de la même façon qu'en électrostatique ou électrocinétique, on déduit la formulation faible associée : 

Trouver $\phi \in \text{H}\_{0}({\bf grad},\Omega) = \\{ \phi \in \text{H}({\bf grad},\Omega) : \phi\|\_{\Gamma_{n}} = 0\\}$, tel que : 

$$\forall \phi' \in \text{H}\_{0}({\bf grad},\Omega),~~ \left(-\mu\\,{\bf grad}\\,\phi\\,,\\,{\bf grad}\\,\phi'\right)\_{\Omega} + \left({\bf b_r}\\,,\\,{\bf grad}\\,\phi'\right)\_{\Omega_a}= 0$$    

    




