---
title: Électrostatique
weight: 15
#pre: "<b>3. </b>"
chapter: false
math : true
---


Dans le cas de l'**électrostatique** (en anglais *electrostatics*), nous nous intéresserons au calcul de la distribution du champ électrique ${\bf e}$ due à des charges statiques ou à différents niveaux de potentiel électrique. 


Les relations intervenant en électrostatique sont : 

- Les équations de Maxwell en statique suivantes : $$\left\\{\begin{aligned}\text{div}\\,{\bf d} &= \rho_q\\\\{\bf rot}\\,{\bf e} &= {\bf 0} \end{aligned}\right.$$

- La loi de comportement dans les milieux diélectriques : $${\bf d} = \varepsilon\\,{\bf e}$$

- Pour les conditions aux limites, c'est-à-dire aux frontières du domaine d'étude $(\partial\Omega = \Gamma = \Gamma_d\cup \Gamma_n)$, nous aurons : 
	* soit, d'après la condition sur la composante tangentielle de ${\bf e}$ : $$\left.{\bf n}\wedge{\bf e}\right|_{\Gamma_d} = {\bf 0}$$ 
	* soit, d'après la condition sur la composante normale de ${\bf d}$ : $$\left.{\bf n}\cdot{\bf d}\right|_{\Gamma_n} = 0$$
	


## Formulation forte

Maxwell-Faraday en statique nous permet de définir le potentiel scalaire électrique ${\bf v}$ tel que : ${\bf e} = -{\bf grad}\\,v$

Ainsi, dans le domaine d'étude $\Omega$, l'équation satisfaite par $v$ est obtenue par substitution dans l'équation de Maxwell-Gauss : $$ \text{div}\left(\varepsilon\\,{\bf grad}\\,v \right) + \rho_q = 0$$ 


{{% notice warning %}}
Attention : En électrostatique, les conducteurs sont supposés « parfaits », le champ électrique est nul à l'intérieur et donc $v$ y est constant.
{{% /notice %}}

En pratique, les conducteurs seront donc exclus du domaine d'étude et seules les conditions sur leurs bords $(\Gamma_k)$ interviendront :   
- soit en tant que condition de Dirichlet où : $$v|_{\Gamma_i} = v_i$$ 
- soit en tant que condition de Neumann où : $$\left.\frac{\partial\\,v}{\partial {\bf n}}\right|\_{\Gamma\_j} = {\bf grad}\\,v\cdot {\bf n}\big|_{\Gamma_j} = -\frac{\sigma\_{q\_j}}{\varepsilon}$$ 

Aux frontières, nous aurons les mêmes conditions mais homogènes : $ v|\_{\Gamma_d} = 0~$ ou $~{\bf grad}\\,v\cdot {\bf n}\big|_{\Gamma_n} = 0$.

Finalement, la forme complète de la formulation forte à résoudre est donc : 

$$\left\\{\begin{aligned}\text{div}\left(\varepsilon\\,{\bf grad}\\,v\right) + \rho_q &= 0~ ,  &\text{dans}~ \Omega\\\\  \left.v\right|\_{\Gamma\_d} &= 0~,  &\text{sur}~ \Gamma\_d \\\\ \left.v\right\|_{\Gamma\_i} &= v_i~,  &\text{sur}~ \Gamma\_i \\\\\left.{\bf grad}\\, v \cdot {\bf n}\right|\_{\Gamma\_n} &= 0~ , &\text{sur}~ \Gamma\_n \\\\\left.{\bf grad}\\, v \cdot {\bf n}\right|\_{\Gamma\_j} &= -\frac{\sigma\_{q\_j}}{\varepsilon}~ , &\text{sur}~ \Gamma\_j\end{aligned}\right.$$



## Formulation faible

En appliquant le [**principe vu dans le chapitre précédent**](../../principe/continu/#formulation-variationnelle), nous en déduisons la formulation faible du problème : 

Trouver $v \in \text{H}\_{0i}({\bf grad},\Omega) = \\{ u \in \text{H}({\bf grad},\Omega) : u\|\_{\Gamma_d} = 0,~ u\|\_{\Gamma_i} = v_i\\}$, tel que : 

$$\forall v' \in \text{H}\_{0i}({\bf grad},\Omega),~~ \left(\varepsilon\\,{\bf grad}\\,v,{\bf grad}\\,v'\right)\_{\Omega} - \left(\rho_q,v'\right)\_{\Omega} + \left<\sigma\_{q\_j},v'\right>\_{\Gamma_j} = 0$$



## Exemples et applications

### Condensateur cylindrique

Nous disposons de tous les outils pour résoudre numériquement l'exemple classique du condensateur cylindrique du premier chapitre ([cf ici](../../electromag/synthese/#ex-2--condensateurs)).

Compte tenu des symétries, le problème pourra se résoudre en 2D axisymétrique sur une demie-géométrie, telle que représentée sur la figure ci-dessous montrant également les conditions aux limites associées ainsi qu'un exemple de maillage : 

![Géométrie et maillage du condensateur cylindrique](../../images/figures/condo_cyl.svg "Géométrie et maillage du condensateur cylindrique") 

Dans ce cas, la formulation faible à résoudre se ramène à : 

Trouver $v \in \text{H}\_{01}({\bf grad},\Omega) = \\{ u \in \text{H}({\bf grad},\Omega) : u\|\_{\Gamma_d} = 0,~ u\|\_{\Gamma_1} = V_1\\}$, tel que : 

$$\forall v' \in \text{H}\_{01}({\bf grad},\Omega),~~ \left(\varepsilon\\,{\bf grad}\\,v,{\bf grad}\\,v'\right)\_{\Omega} = 0$$

Dans GetDP, cela se traduit par : 
```c++
Constraint {	
  {Name TensionsImposees ;
    Case {      
      { Region Gamma1 ; Type Assign ; Value V1 ; }
      { Region Masse ; Type Assign ; Value 0 ; }
      { Region Dirichlet ; Type Assign ; Value 0 ; }
    }
  }
}

FunctionSpace {
  { Name Hgrad ; Type Form0 ; 
    BasisFunction { 
      { Name sn ; NameOfCoef vn ; Function BF_Node ; 
			Support Region[{Domaine}]  ; Entity NodesOf[All] ; }
    } 
    Constraint {
      { NameOfCoef vn ; EntityType NodesOf ; 
			NameOfConstraint TensionsImposees ; }
    }
  }
}

Formulation {
  { Name Electrostat ; Type FemEquation ;
    Quantity {
      { Name v  ; Type Local  ; NameOfSpace Hgrad ; }
    }
    Equation {
      Galerkin { [ eps[]*Dof{Grad v}  , {Grad v} ] ;
		In Domaine ; Jacobian Jvol ; Integration Integ ; }
    }
  }
}
```

#### Explications :

1. On définit tout d'abord les contraintes sur le potentiel $v$.
2. Celles-ci permettent de définir ensuite l'espace fonctionnel dans lequel se trouve $v$. On l'appelle ici `Hgrad` (correspond au $W^0$ du [chapitre précédent](../../principe/discret/whitney/#espaces-discrets)) qui approxime $\text{H}\_{01}({\bf grad},\Omega)$. On utilise des éléments nodaux avec les fonctions de base $s_n$ vues précédemment. 
3. Enfin, nous définissons la forme faible du problème.   



Après résolution, on obtient la distribution du potentiel scalaire électrique :
![v dans le domaine](../../images/figures/v_condo_cyl.png "v dans le domaine")

Et on peut calculer la valeur de la capacité à partir de l'énergie électrostatique.  

**Vous pouvez télécharger les fichiers complets en** {{% button href="../../files/condo_cylindrique.zip" icon="fas fa-download" icon-position="right" %}}cliquant ici{{% /button %}}.

---

### Condensateurs plans 

1. Adapter l'exemple précédent pour résoudre le problème similaire du condensateur plan à armatures rectangulaires :  
	- modifier la géométrie ;
	- changer de jacobien ;
	- adapter les formules de calcul de l'énergie et de capacité. 
2. Étudier également le cas d'un condensateur plan mais, cette fois, à armatures circulaires.

---
 
 
###  Potentiel Flottant 

Dans des problèmes tels que définis ci-dessus, nous n'avons pas directement accès à la charge portée par les armatures (il faut nécessairement passer par des calculs post-processeur). Nous ne pouvons pas non plus proprement considérer cette charge comme une entrée du problème pour calculer la différence de potentiels associée.  
Nous pourrions penser à utiliser une condition de Neumann non homogène sur l'armature portant le potentiel $V_1$ mais la valeur du potentiel résultant du calcul ne serait plus constante le long de l'armature.

Pour pallier cet inconvénient, les auteurs de GetDP ont implanté une fonctionalité très pratique : les ***Global quantities*** (grandeurs globales) qui permettent de définir ce qu'on appelle un **potentiel flottant** (*floating potential*) via un terme global (*global term*) dans la formulation.    

Plutôt que de faire une explication un peu trop appoximative, je préfère vous renvoyer à l'exemple du wiki de ONELAB détaillant son principe de fonctionnement : [**Electrostatics with floating potentials**](https://gitlab.onelab.info/doc/tutorials/-/wikis/Electrostatics-with-floating-potentials) : 
1. Télécharger les fichiers et lire attentivement les commentaires du `.pro` (oui, ça relève de la magie !). 
2. Adapter les exemples précédents pour les résoudre en potentiel flottant. 

Comme je ne suis pas méchant, je vous donne la **solution pour le condensateur cylindrique** en {{% button href="../../files/condo_cylindrique_pf.zip" icon="fas fa-download" icon-position="right" %}}cliquant ici{{% /button %}}.






