---
title: Méthode de Galerkin et éléments finis
menutitle: Méthode de Galerkin et EF
chapter: false
weight: 9
markup: "goldmark"
math: "true" 
---

## Méthode de Galerkin

Nous avons vu dans la section précédente que la forme faible de chaque problème considéré pouvait se mettre sous la forme :

$$\left\\{\begin{aligned}~ &\text{Trouver}~ u \in V ~ \text{tel que :}\\\\ &a(u,v) = L(v),~ ~ \forall\\,v \in V\end{aligned}\right.$$


$V$ étant de dimension infinie, un tel problème est particulièrement difficile à résoudre. La méthode de Galerkin consiste à résoudre la formulation faible dans un sous-espace $V\_h \sub V$ de dimension finie $n_h$ possédant les mêmes propriétés, soit :

$$\left\\{\begin{aligned} ~ &\text{Trouver}~ u\_h \in V\_h ~ \text{tel que :}\\\\ &a(u\_h,v\_h) = L(v\_h),~ ~ \forall\\,v\_h \in V\_h\end{aligned}\right.$$
où $u_h$ est une solution approchée de la solution exacte $u$. 

L'idée est de résoudre cette formulation à partir d'une base $(\varphi_1,\varphi_2,\dots,\varphi\_{n_h})$ de $V_h$. En décomposant $u_h$ dans cette base, on a :

$$u_h = \sum\limits\_{j=1}^{n\_h} u_j\\,\varphi_j$$

Le principe de la méthode de Galerkin est alors d'utiliser les fonctions de base $\varphi_i$ comme fonctions test dans la formulation faible. Ainsi :

$$\begin{aligned}\forall i \in [\\![1,n\_h]\\!]~ ,~ &a\left(\sum\limits\_{j=1}^{n\_h} u_j\\,\varphi_j,\varphi_i\right) = L(\varphi_i)\\\\ & \sum\limits\_{j=1}^{n\_h} u_j\\,a(\varphi_j,\varphi_i) = L(\varphi_i)\end{aligned} $$

Soit : 
$$\boxed{\forall i \in [\\![1,n\_h]\\!]~ ,~ \sum\limits\_{j=1}^{n\_h} a(\varphi_i,\varphi_j)\\,u_j = L(\varphi_i)}$$

En définissant les vecteurs ${\bf U_h} = \left( u_i \right)\_{1\leq i \leq n_h}$ et ${\bf B\_h} = \big( L(\varphi_i) \big)\_{1\leq i \leq n\_h}$, et la matrice ${\bf A_h} = \big( a(\varphi_i,\varphi_j) \big)\_{1\leq i,j\leq n_h}$, le problème peut se mettre sous la forme matricielle :

$$\boxed{{\bf A_h} \\, {\bf U_h} = {\bf B_h}}$$

En résolvant ce système linéaire, on obtient alors les composantes $u_i$ de la solution approchée $u_h$ dans la base $(\varphi_i)\_{1\leq i\leq n_h}$. 

**$\rightarrow$ La méthode des éléments finis permet d'appliquer ce principe de résolution.** 


## Qu'est-ce qu'un élément fini ?

On appelle élément fini le triplet $(K,P\_K,\Sigma\_K)$, où :
* $K$ est un **domaine** de l'espace appelé **élément géométrique** (généralement de forme simple : un segment, un triangle, un quadrangle, un tétraèdre, un hexaèdre, une pyramide, un prisme) ;
* $P\_K$ est un **espace fonctionnel de dimension finie** $n\_K$, défini sur $K$ engendré par ce qu'on appelle les **fonctions de base** $p_i, 1 \leq i \leq n\_K$ ;
* $\Sigma\_K$ est un ensemble de $n\_K$ **degrés de liberté** représentés par $n\_K$ fonctionnelles (formes) linéaires $\sigma\_i,~ 1 \leq i \leq n\_K,$ définies sur l'espace $P\_K$ et à valeurs dans $\mathbb{R}$.

De plus, il faut qu'il existe une unique fonction de $P\_K$ prenant des valeurs données aux degrés de liberté de $\Sigma\_K$ : cette dernière condition définit l'**unisolvance** de l'élément fini $(K,P\_K,\Sigma\_K)$. 

Nous allons maintenant voir comment mettre en place la méthode basée sur ces éléments. 


