
Include "data_ventouse.geo";

Group{
    Domaine = Region[{AIRINF,AIRSUP,ENTREFER,CIRCUITMAG,BOBINEALLER,BOBINERETOUR,PLAQUE}];
    Domaine_NonMag = Region[{AIRINF,AIRSUP,ENTREFER,BOBINEALLER,BOBINERETOUR}];
    Domaine_Mag = Region[{CIRCUITMAG,PLAQUE}];
    Entrefer = Region[{ENTREFER}];
    BobineAller = Region[{BOBINEALLER}];
    BobineRetour = Region[{BOBINERETOUR}];
    Bobines =  Region[{BOBINEALLER,BOBINERETOUR}];
    Dirichlet = Region[{DIRICHLET}];
}

Function{
    mu0 = 4e-7*Pi;
    mur = 500;
    N = 200;
    I = 0.5*b*c/N*2e6;
    Lz = 20e-2;
    nu[#{Domaine_NonMag}] = 1.0/mu0;
    nu[#{Domaine_Mag}] = 1.0/(mu0*mur);
    j[#{BobineAller}] = Vector[0,0,N*I/(b*c)];
    j[#{BobineRetour}] = Vector[0,0,-N*I/(b*c)];
}

Jacobian{
    { Name Jvol;
      Case {
        { Region All ; Jacobian Vol ; }
      }
    }
  }
  
  Integration {
    { Name Integ;
      Case { 
        {Type Gauss;
      Case { 
        { GeoElement Line ; NumberOfPoints 2; }
        { GeoElement Triangle ; NumberOfPoints 6; } }
        }
      }
    }
  }

  Constraint {	
    {Name Dirichlet ;
      Case {      
        { Region Dirichlet ; Type Assign ; Value 0. ; }
      }
    }
  }

  FunctionSpace {
    { Name Hrot ; Type Form1 ; 
      BasisFunction { 
        { Name se ; NameOfCoef ae ; Function BF_PerpendicularEdge ; 
            Support Region[{Domaine}]  ; Entity NodesOf[All] ; }
      } 
      Constraint {
        { NameOfCoef ae  ; EntityType NodesOf ; NameOfConstraint Dirichlet ; }
      }
    }
  }

  Formulation {
    { Name Magnetostat ; Type FemEquation ;
      Quantity {
        { Name a  ; Type Local  ; NameOfSpace Hrot ; }
      }
     Equation {
       
        Galerkin { [ nu[]*Dof{Curl a}  , {Curl a} ] ;
          In Domaine ; Jacobian Jvol ; Integration Integ ; }

	Galerkin { [ -j[]  , {a} ] ;
          In Bobines ; Jacobian Jvol ; Integration Integ ; }
	
      }
    }
  }
  
  Resolution {
    { Name analyse ;
      System {
        { Name Sys ; NameOfFormulation Magnetostat ; }
      }
      Operation {
        Generate[Sys] ; 
        Solve[Sys] ;
        SaveSolution[Sys] ;
      }
    }
  }

  PostProcessing {
    { Name PostProc ; NameOfFormulation Magnetostat ;
      Quantity {	
        { Name a  ; Value { Term { [ {a} ] ; In Domaine ; Jacobian Jvol ; } } }
	{ Name az  ; Value { Term { [ Norm[{a}] ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name b  ; Value { Term { [ {Curl a} ] ; In Domaine ; Jacobian Jvol ; } } }
        { Name h  ; Value { Term { [ nu[]*{Curl a} ] ; In Domaine ; Jacobian Jvol ; } } }
	{ Name F_TM ; Value { Integral { [ 1/(2*mu0)*(CompY[{Curl a}]^2-CompX[{Curl a}]^2)*Lz/entrefer ] ;
	      In Entrefer ; Jacobian Jvol ; Integration Integ ;} } } 
	{ Name L ; Value { Integral { [ N*Lz*Norm[{a}]/(b*c)/I ]  ; In Bobines ; 
	      Jacobian Jvol ; Integration Integ ;} } } 
      }
    }
  }
  
  PostOperation PostOp UsingPost PostProc {
    Print[ a, OnElementsOf Domaine, File "a.pos"] ;
    Print[ az, OnElementsOf Domaine, File "az.pos"] ;
    Echo[ Str["View[1].IntervalsType = 1;", "View[1].NbIso = 30;", "View[1].LightLines = 0;"], 
      File "tmp.geo", LastTimeStepOnly ];
    Print[ b, OnElementsOf Domaine, File "b.pos"] ;
    Print[ h, OnElementsOf Domaine, File "h.pos"] ;
    Print[ F_TM[Entrefer], OnGlobal, File "force.dat", 
      SendToServer "Modele/Resultats/1Force par Tenseur moyenné (N)", Color "AliceBlue" ];
    Print[ L[Bobines], OnGlobal, File "inductance.dat", 
      SendToServer "Modele/Resultats/2Inductance (H)", Color "AliceBlue" ];  
  }