---
title: "Grandeurs globales : forces"
menutitle: "Forces"
draft: false
weight: 4
markup: "goldmark"
math: "true" 
---


## Force de Lorentz 
 
Initialement énoncée pour une particule portant une charge élémentaire $q$, la force de Lorentz est donnée par :

$${\bf f} = q\\,\left({\bf e} + {\bf v}\wedge{\bf b}\right)$$

Cette expression peut se généraliser au cas d'une distribution volumique de sources (densités volumiques de charge $\rho_q$ et de courant ${\bf j}$) par :

$${\bf f\_{em}} = \underbrace{\rho_q\\,{\bf e}}\_{{\bf f_C}} + \underbrace{{\bf j}\wedge{\bf b}}\_{{\bf f_L}}$$

Où la densité volumique de force ${\bf f\_{em}}$, se décompose en deux termes :
1. la densité volumique de force de Coulomb ${\bf f_C}$,
2. la densité volumique de force de Laplace ${\bf f_L}$. 

{{% notice warning %}}
**Attention :** La formule ci-dessus n'est valable qu'en l'absence de milieu diélectrique ou ferromagnétique. Pour l'utiliser dans le cas général (même dans l'ARQS), il faudrait rajouter les termes correspondant à la densité de charges liées pour la force de Coulomb, et ceux liés à la densité de courants d'aimantation pour celle de Laplace (les courants induits étant pris en compte dans ${\bf j}$). 
Soit quelque chose qui pourrait ressembler à :
$${\bf f\_{em}} = (\rho_q-\text{div}\\,{\bf p})\\,{\bf e} + ({\bf j} + {\bf rot\\,m})\wedge{\bf b}$$
**Ainsi, en dehors du cas particulier du vide (ou de milieux analogues comme l'air), cette formule est difficilement exploitable.** C'est pourquoi nous préférerons utiliser une approche énergétique.
{{% /notice %}}

---

## Approche énergétique

### Aspects thermodynamiques

Le système considéré étant fermé (sans échange de matière avec l'extérieur), le premier principe de la thermodynamique nous permet d'écrire la variation de son énergie interne $\mathcal{U}$ :

$$\text{d}\\,\mathcal{U} = \text{d}\\,\mathcal{Q} + \text{d}\\,\mathcal{W}$$

avec :
* $\text{d}\\,\mathcal{Q}$, la quantité de chaleur fournie par l'extérieur au système,
* $\text{d}\\,\mathcal{W}$, le travail fourni par l'extérieur au système (comprenant l'effet des forces électromagnétiques).

Dans le cas de transformations réversibles, le deuxième principe nous donne :

$$\text{d}\\,\mathcal{Q} = T~\text{d}\\,\mathcal{S} $$

$T$ et $\mathcal{S}$ étant respectivement la température et l'entropie du système. 

L'énergie interne est alors une fonction dont une des variables naturelles est $\mathcal{S}$. Pour faciliter la résolution de certains problèmes, les thermodynamiciens ont l'habitude de définir d'autres grandeurs énergétiques en ajoutant des termes à l'énergie interne. 

Ainsi, on peut définir l'**énergie libre** par :

$$\mathcal{F} = \mathcal{U} - T\\,\mathcal{S}$$

On a alors : 

$$\begin{aligned}\text{d}\\,\mathcal{F} &= \text{d}\\,\mathcal{U} - \text{d}\\,(T\\,\mathcal{S})\\\ &= \cancel{T~\text{d}\\,\mathcal{S}} + \text{d}\\,\mathcal{W} - \cancel{T~\text{d}\\,\mathcal{S}} - \mathcal{S}~\text{d}\\,T\end{aligned}$$

Soit : $$\boxed{\text{d}\\,\mathcal{F} = -\mathcal{S}~\text{d}\\,T+\text{d}\\,\mathcal{W}}$$

Revenons à l'échelle locale en définissant les densités volumiques correspondant à nos grandeurs énergétiques :

$$\left\\{\begin{array}{c} \displaystyle \mathcal{f} = \frac{\text{d}\\,\mathcal{F}}{\text{d}\\,V} \\\\[3ex] \displaystyle \mathcal{s} = \frac{\text{d}\\,\mathcal{S}}{\text{d}\\,V} \\\\[3ex] \displaystyle \mathcal{w} = \frac{\text{d}\\,\mathcal{W}}{\text{d}\\,V}\end{array}\right.$$


Les variations temporelles correspondantes sont ainsi :

$$\begin{aligned}\frac{\partial\\,\mathcal{f}}{\partial t} &= -\mathcal{s}\\, \frac{\partial\\,T}{\partial t} + \frac{\partial\\,\mathcal{w}}{\partial t}\\\\[2ex] &= -\mathcal{s}\\,\frac{\partial\\,T}{\partial t} + \frac{\partial\\,\mathcal{w\_{em}}}{\partial t} + \frac{\partial\\,\mathcal{w\_{\ne em}}}{\partial t}\end{aligned}$$

en séparant dans $\mathcal{w}$ la partie liée aux électromagnétiques $\mathcal{w\_{em}}$ de celle liée aux autres phénomènes physiques $\mathcal{w\_{\ne em}}$.

En réinjectant le bilan de puissance vu en début de section, on obtient finalement : 
$$\boxed{\frac{\partial\\,\mathcal{f}}{\partial t} = -\mathcal{s}\\,\frac{\partial\\,T}{\partial t} + {\bf e}\cdot{\bf j} + {\bf h}\cdot\frac{\partial\\,{\bf b}}{\partial t} + {\bf e}\cdot\frac{\partial\\,{\bf d}}{\partial t} + \frac{\partial\\,\mathcal{w\_{\ne em}}}{\partial t}}$$


### Application aux phénomènes purement magnétiques

En considérant que notre système est le siège d'effets purement magnétiques, la variation de la densité d'**énergie libre magnétique** (qu'on notera dans ce cas $f_m$) ne contient plus que les termes suivants :

$$\text{d}\\,\mathcal{f_m} = -\mathcal{s}~ \text{d} \\,T + {\bf h}\cdot{\bf d b} = -\mathcal{s}~\text{d}\\,T + \text{d}\\,w_{mag}$$

{{% notice note %}}
On remarque donc le lien entre énergie libre et énergie magnétique. À température fixée, les deux sont identiques. En fait, compte tenu de la différence d'ordre de grandeur des constantes de temps thermiques et électromagnétiques, **on pourra toujours considérer que l'énergie magnétique telle que nous l'avons définie est l'énergie libre du système**.  
{{% /notice %}}
 
#### Température et flux constants

Dans le cadre d'une **transformation à température et flux magnétique constants** (et donc à induction constante), nous aurons :

$$\text{d} \\,\mathcal{f_m} = 0 ~~ \Rightarrow ~~ \text{d}\\,\mathcal{F_m} = 0$$
 
Ainsi, si nous voulons calculer la force ${\bf F_m}$ d'origine magnétique s'exerçant sur un élément du système pouvant se déplacer selon la coordonnée généralisée ${\bf x_0}$ à flux constant, il suffit d'écrire la variation d'énergie correspondante (en utilisant le travail de cette force) :

$$\text{d}\\,\mathcal{F_m} = {\bf F_m}\cdot{\bf d x_0} + {\bf grad\_{x_0}}\\,(\mathcal{F_m})\cdot{\bf d x_0}$$

Puisque $\text{d}\\,\mathcal{F_m} = 0$, et ${\bf grad\_{x_0}}\\,(\mathcal{F_m})=  {\bf grad\_{x_0}}\\,(W\_{mag})$, on en déduit l'expression de la force : 

$${\bf F_m} = - {\bf grad\_{x_0}}\\,(W\_{mag})$$

Ou encore, en exprimant la composante dans la direction de ${\bf x_0}$ :

$$\boxed{F_m = - \left(\frac{\partial\\,W\_{mag}}{\partial\\,x_0}\right)\_{\varphi~\text{cst}}}$$



#### Température et courant constants

Dans le cas d'une transformation où ce sont les courants qui sont maintenus constants, il convient de définir un nouveau potentiel thermodynamique $\mathcal{g_m}$ par : 

$$\mathcal{g_m} = \mathcal{f_m} - {\bf h}\cdot{\bf b}$$

Alors :

$$\text{d}\\,\mathcal{g_m} = -\mathcal{s}~\text{d}\\,T + \cancel{{\bf h}\cdot{\bf d b}} - \cancel{{\bf h}\cdot{\bf d b}} - {\bf b}\cdot{\bf d h}$$

Soit : 
$$\text{d}\\,\mathcal{g_m} = -\mathcal{s}~\text{d}\\,T - {\bf b}\cdot{\bf d h} = -\mathcal{s} ~ \text{d}\\,T - \text{d}\\,\widetilde{w}\_{mag}$$

Cette nouvelle grandeur énergétique $\mathcal{G_m}$, de densité volumique $\mathcal{g_m}$ est l'**enthalpie libre magnétique** (ou **énergie libre de Gibbs**) du système.

{{% notice note %}}
On notera le lien avec la coénergie telle que définie précédemment. En fait nous pourrons considérer que **la coénergie magnétique est l'opposée de l'enthalpie libre magnétique** (à température fixée).
{{% /notice %}}

Dans le cadre d'une **transformation à température et courants constants** (et donc à champ magnétique constant), nous aurons :

$$\text{d} \\,\mathcal{g_m} = 0 ~~ \Rightarrow ~~ \text{d}\\,\mathcal{G_m} = 0$$

En procédant comme dans le paragraphe précédent pour calculer la force d'origine magnétique s'exerçant sur l'élément considéré, on obtient :
 
$$\text{d}\\,\mathcal{G_m} = {\bf F_m}\cdot{\bf d x_0} + {\bf grad\_{x_0}}\\,(\mathcal{G_m})\cdot{\bf d x_0}$$

Soit :

$${\bf F_m} = - {\bf grad\_{x_0}}\\,(\mathcal{G_m}) = + {\bf grad\_{x_0}}\\,(\widetilde{W}\_{mag})$$

Ou encore, en exprimant la composante dans la direction de ${\bf x_0}$ :

$$\boxed{F_m = + \left(\frac{\partial\\,\widetilde{W}\_{mag}}{\partial\\,x_0}\right)\_{I~\text{cst}}}$$


{{% notice tip %}}
Les formules précédentes peuvent aussi être utilisées pour calculer des couples. Si un couple $\Gamma$ d'origine magnétique s'exerce sur notre élément du système suivant la position angulaire généralisée $\alpha_0$. On aura :
$$\Gamma = - \left(\frac{\partial\\,W\_{mag}}{\partial\\,\alpha_0}\right)\_{\varphi~\text{cst}} = + \left(\frac{\partial\\,\widetilde{W}\_{mag}}{\partial\\,\alpha_0}\right)\_{I~\text{cst}}$$
{{% /notice %}}



### Application aux phénomènes électrostatiques

Dans le cas de phénomènes électrostatiques, la densité volumique d'énergie libre électrostatique $\mathcal{f_e}$ est, d'après ce qui précède :

$$\text{d}\\,\mathcal{f_e} = -\mathcal{s}~ \text{d} \\,T + {\bf e}\cdot{\bf d\\,d} = -\mathcal{s}~\text{d}\\,T + \text{d}\\,w_{el}$$


#### Température et charges constantes

Dans le cadre d'une **transformation à température et charges électriques constantes** (et donc à induction constante), nous aurons :

$$\text{d} \\,\mathcal{f_e} = 0 ~~ \Rightarrow ~~ \text{d}\\,\mathcal{F_e} = 0$$
 
Ainsi, si nous voulons calculer la force ${\bf F_m}$ d'origine magnétique s'exerçant sur un élément du système pouvant se déplacer selon la coordonnée généralisée ${\bf x_0}$ à flux constant, il suffit d'écrire la variation d'énergie correspondante (en utilisant le travail de cette force) :

$$\text{d}\\,\mathcal{F_e} = {\bf F_e}\cdot{\bf d x_0} + {\bf grad\_{x_0}}\\,(\mathcal{F_e})\cdot{\bf d x_0}$$

Puisque $\text{d}\\,\mathcal{F_e} = 0$, et ${\bf grad\_{x_0}}\\,(\mathcal{F_e})=  {\bf grad\_{x_0}}\\,(W\_{el})$, on en déduit l'expression de la force : 

$${\bf F_e} = - {\bf grad\_{x_0}}\\,(W\_{el})$$

Ou encore, en exprimant la composante dans la direction de ${\bf x_0}$ :

$$\boxed{F_e = - \left(\frac{\partial\\,W\_{el}}{\partial\\,x_0}\right)\_{Q~\text{cst}}}$$


#### Température et tensions constantes

Dans le cas d'une transformation où ce sont les tensions qui sont maintenues constants, il convient de définir un nouveau potentiel thermodynamique $\mathcal{g_e}$ par : 

$$\mathcal{g_e} = \mathcal{f_e} - {\bf e}\cdot{\bf d}$$

Alors :

$$\text{d}\\,\mathcal{g_e} = -\mathcal{s}~\text{d}\\,T + \cancel{{\bf e}\cdot{\bf d\\,d}} - \cancel{{\bf e}\cdot{\bf d\\,d}} - {\bf d}\cdot{\bf d e}$$

Soit : 
$$\text{d}\\,\mathcal{g_e} = -\mathcal{s} ~ \text{d}\\,T - {\bf d}\cdot{\bf d e} = -\mathcal{s}~\text{d}\\,T - \text{d}\\,\widetilde{w}\_{el}$$

Cette nouvelle grandeur énergétique $\mathcal{G_e}$, de densité volumique $\mathcal{g_e}$ est l'**enthalpie libre électrostatique** (ou **énergie libre de Gibbs**) du système.

Dans le cadre d'une **transformation à température et tensions constantes** (et donc à champ électrique constant), nous aurons :

$$\text{d} \\,\mathcal{g_e} = 0 ~~ \Rightarrow ~~ \text{d}\\,\mathcal{G_e} = 0$$

En procédant comme dans le paragraphe précédent pour calculer la force d'origine électrostatique s'exerçant sur l'élément considéré, on obtient :

$$\text{d}\\,\mathcal{G_e} = {\bf F_e}\cdot{\bf d x_0} + {\bf grad\_{x_0}}\\,(\mathcal{G_e})\cdot{\bf d x_0}$$

Soit :

$${\bf F_e} = -{\bf grad\_{x_0}}\\,(\mathcal{G_e}) = + {\bf grad\_{x_0}}\\,(\widetilde{W}\_{el})$$

Ou encore, en exprimant la composante dans la direction de ${\bf x_0}$ :

$$\boxed{F_e = + \left(\frac{\partial\\,\widetilde{W}\_{el}}{\partial\\,x_0}\right)\_{V~\text{cst}}}$$

---

## Tenseur des contraintes électromagnétiques de Maxwell
 
### Densité volumique de forces 
 
Comme très brièvement dit en début de page, l'expression de la densité volumique de force électromagnétique est difficilement exploitable en pratique. 

En fait, il existe plusieurs façons de la formuler et aucune ne fait encore consensus. Quelle que soit l'approche utilisée, il faut considérer les opérateurs différentiels agissant sur nos champs au sens des distributions, et plusieurs termes surfaciques interviennent alors. Ces derniers correspondent aux éventuelles densités surfaciques de sources, mais aussi aux discontinuités de paramètres physiques (perméabilité, réluctivité, aimantation) dues aux changements de milieux. 

Néanmoins, dans le cas d'un milieu homogène isotrope, on peut tout de même obtenir une formulation de cette densité volumique de force.   
Repartons de la formule :

$${\bf f\_{em}} = (\rho_q-\text{div}\\,{\bf p})\\,{\bf e} + ({\bf j} + {\bf rot\\,m})\wedge{\bf b}$$

En y réinjectant les équations de Maxwell-Ampère et Maxwell-Gauss et en utilisant les lois de comportement ${\bf d} = \varepsilon_0\\,{\bf e} + {\bf p}$ et ${\bf b} = \mu_0\\,({\bf h} + {\bf m)}$, on obtient : 

$$\boxed{{\bf f\_{em}} = \varepsilon_0\\,(\text{div}\\,{\bf e})\\,{\bf e} + \frac{1}{\mu_0}\\,{\bf rot\\,b}\wedge{\bf b}}$$

Dans le cas de plusieurs milieux (et c'est généralement toujours le cas), il nous faut malheureusement rajouter les termes liés aux interfaces pour calculer la densité de force partout et pouvoir en déduire les forces ou couples s'exerçant globalement sur les pièces mobiles. 

Nous disposons cependant d'une méthode plus pratique pour calculer ces forces globales : le tenseur de Maxwell.


### Tenseur de Maxwell

Soit $\overline{\overline{{\bf T}}}$ champ de tenseur d'ordre 2, continûment différentiable sur le domaine d'étude $V$, tel que : 

$${\bf f_{em}} = \overline{\text{div}}\\,\overline{\overline{{\bf T}}}$$

Ainsi, la force totale ${\bf F_{em}}$ s'exerçant sur un sous-domaine quelconque $\Omega \subset V$ peut se réduire à l'intégrale surfacique de $\overline{\overline{{\bf T}}}$ sur son bord $\partial \Omega$ via le théorème de la divergence :

$${\bf F\_{em}} = \iiint\_{\Omega} {\bf f\_{em}} ~ \text{d} V = \iiint\_{\Omega} \overline{\text{div}}\\,\overline{\overline{{\bf T}}}~\text{d} V = \oiint\_{\partial \Omega} \overline{\overline{{\bf T}}}\cdot{\bf d S}$$

Le tenseur ainsi défini n'est pas unique et peut comprendre des termes difficiles à évaluer, en particulier aux interfaces entre les différents milieux. Mais on peut simplifier grandement les choses en :
* **choisissant un domaine $\Omega$ entourant entièrement l'élément sur lequel on veut calculer les forces**, 
* et **dont la frontière $\partial \Omega$ se situe à l'intérieur d'un unique milieu matériel** (donc sans traverser d'interface).
 
Dans ce cas, la formule communément admise pour le champ de tenseur sur la frontière $\partial \Omega$ est : 

$$\boxed{\overline{\overline{{\bf T}}} = \varepsilon_0\\,{\bf e}\otimes{\bf e} + \frac{1}{\mu_0}\\,{\bf b}\otimes{\bf b} - \frac{\delta}{2}\left(\varepsilon_0\\,{\bf e}^2 + \frac{{\bf b}^2}{\mu_0}\right)}$$

où $\otimes$ est le produit tensoriel et $\delta$ le tenseur unité d'ordre 2. 

{{% notice note %}}
Les termes du tenseur s'expriment en $\text{N}\cdot\text{m}^{-2}$, ils sont donc homogènes à une pression (on l'appelle souvent « pression électromagnétique »). Les mécaniciens parlent plutôt de « contraintes », c'est pourquoi le tenseur est généralement appelé **tenseur des contraintes électromagnétiques de Maxwell**.
{{% /notice %}}

Dans la suite, nous traiterons séparément les parties magnétiques et électrostatiques.

#### Partie magnétique
 
Si on ne considère que les effets magnétiques, le terme général du tenseur est : 

$$\left(T_{ij}\right) = \frac{1}{\mu_0}\\,b_i\\,b_j - \frac{\delta_{ij}}{2\\,\mu_0} {\bf b}^2$$

Et sa représentation matricielle dans le repère cartésien est donc :

$$\boxed{\overline{\overline{{\bf T}}} = \frac{1}{\mu_0} \begin{pmatrix} b_x^2 - \frac{{\bf b}^2}{2} & b_x\\,b_y & b_x\\,b_z \\\\ b_x\\,b_y & b_y^2 - \frac{{\bf b}^2}{2} & b_y\\,b_z \\\\ b_x\\,b_z & b_y\\,b_z & b_z^2 - \frac{{\bf b}^2}{2}\end{pmatrix}}$$

$\longrightarrow$ Vérifions que cette définition est correcte.

La densité de force dans le milieu considéré est :

$${\bf f_m} = \begin{pmatrix}f_{m_x}\\\\f_{m_y}\\\\f_{m_z}\end{pmatrix}=\frac{1}{\mu_0}\\,{\bf rot\\,b}\wedge{\bf b}=\frac{1}{\mu_0}\\,\begin{pmatrix}b_y\\,(\partial_y b_x-\partial_x b_y)+b_z\\,(\partial_z b_x - \partial_x b_z)\\\\ b_x\\,(\partial_x b_y-\partial_y b_x)+b_z\\,(\partial_z b_y - \partial_y b_z)\\\\b_x\\,(\partial_y b_x - \partial_x b_y)+b_y\\,(\partial_y b_z-\partial_z b_y)\end{pmatrix}$$


Calculons la première ligne de $\overline{\text{div}}\\,\overline{\overline{\bf T}}$ : 

$$\begin{aligned}\big(\overline{\text{div}}\\,\overline{\overline{\bf T}}\big)\_x &= \frac{1}{\mu_0}\\,\big(b_x\\,\partial_x b_x - b_y\\,\partial_x b_y - b_z\\,\partial_x b_z + b_y\\,\partial_y b_x + b_x\\,\partial_y b_y + b_z\\,\partial_z b_x + b_x\\,\partial_z b_z\big)\\\\ &= \frac{1}{\mu_0}\\,\big(b_x\\,\cancel{(\partial_x b_x+\partial_y b_y+\partial_z b_z)}+ b_y\\,(\partial_y b_x-\partial_x b_y)+b_z\\,(\partial_z b_x - \partial_x b_z)\big)=f_{m_x}\end{aligned}$$

**Remarque :** la simplification vient de $\text{div}\\,{\bf b} = 0$. On pourrait faire de même pour la deuxième et troisième ligne. 

Au final, on retrouve bien $\overline{\text{div}}\\,\overline{\overline{{\bf T}}}={\bf f_m}$, le tenseur est bien défini dans le milieu où se situe la frontière du domaine d'intégration.


#### Partie électrostatique

Du côté électrostatique, la densité volumique de forces est :

$${\bf f_{e}} = \begin{pmatrix}f_{e_x}\\\\f_{e_y}\\\\f_{e_z}\end{pmatrix}=\varepsilon_0\\,\left(\text{div}\\,{\bf e}\right)\\,{\bf e} = \varepsilon_0\\,\left(\partial_x e_x + \partial_y e_y + \partial_z e_z\right)\\,\begin{pmatrix}{e_x}\\\\{e_y}\\\\{e_z}\end{pmatrix}$$

Si on ne considère que les effets électrostatiques, le terme général du tenseur est : 

$$\left(T_{ij}\right) = \varepsilon_0\\,e_i\\,e_j - \frac{\delta_{ij}}{2}\\,\varepsilon_0\\,{\bf e}^2$$

Et sa représentation matricielle dans le repère cartésien est donc :

$$\boxed{\overline{\overline{{\bf T}}} = \varepsilon_0 \begin{pmatrix} e_x^2 - \frac{{\bf e}^2}{2} & e_x\\,e_y & e_x\\,e_z \\\\ e_x\\,e_y & e_y^2 - \frac{{\bf e}^2}{2} & e_y\\,e_z \\\\ e_x\\,e_z & e_y\\,e_z & e_z^2 - \frac{{\bf e}^2}{2}\end{pmatrix}}$$

$\longrightarrow$ Vérifions que cette définition est correcte.

Calculons la première ligne de $\overline{\text{div}}\\,\overline{\overline{\bf T}}$ :

$$\begin{aligned}\big(\overline{\text{div}}\\,\overline{\overline{\bf T}}\big)\_x &= \varepsilon_0\\,\big(e_x\\,\partial_x e_x - e_y\\,\partial_x e_y - e_z\\,\partial_x e_z + e_y\\,\partial_y e_x + e_x\\,\partial_y e_y + e_z\\,\partial_z e_x + e_x\\,\partial_z e_z\big)\\\\ &= \varepsilon_0\\,\big(e_x\\,(\partial_x e_x+\partial_y e_y+\partial_z e_z)+ e_y\\,\cancel{(\partial_y e_x-\partial_x e_y)}+e_z\\,\cancel{(\partial_z e_x - \partial_x e_z)}\big)=f_{e_x}\end{aligned}$$

**Remarque :** les simplifications viennent directement du fait qu'en électrostatique : ${\bf rot\\,e} = {\bf 0}$. On pourrait faire de même pour la deuxième et troisième ligne. 
 
Au final, on retrouve bien $\overline{\text{div}}\\,\overline{\overline{{\bf T}}}={\bf f_e}$, le tenseur est bien défini dans le milieu où se situe la frontière du domaine d'intégration.


### Synthèse

Faisons une petite synthèse de ce qui précède sur un exemple purement théorique. 

Considérons un système électromagnétique de volume $V$, contenant des domaines conducteurs $V_c$ parcourus par des courants, des domaines aimantés $V_a$, et des domaines ferromagnétiques $V_m$. Le reste du domaine est constitué d'air. On désire calculer la force magnétique ${\bf F}$ s'exerçant sur l'élément correspondant au volume $V_f$. Une représentation patatoïde est donnée ci-dessous.

{{< figure src="../../../images/figures/tenseurMax.svg" title="Représentation très schématique du problème">}}

Il nous suffit alors de définir un domaine $\Omega$ entourant $V_f$ dont la frontière $\partial\Omega$ passe uniquement dans l'air environnant $V_f$ et d'appliquer :

$${\bf F}=\begin{pmatrix}F_x\\\\ F_y\\\\ F_z\end{pmatrix} = \oiint\limits\_{\partial\Omega} \overline{\overline{{\bf T}}}\cdot{\bf d S}$$

avec :

$$\overline{\overline{{\bf T}}} = \frac{1}{\mu_0} \begin{pmatrix} b_x^2 - \frac{{\bf b}^2}{2} & b_x\\,b_y & b_x\\,b_z \\\\ b_x\\,b_y & b_y^2 - \frac{{\bf b}^2}{2} & b_y\\,b_z \\\\ b_x\\,b_z & b_y\\,b_z & b_z^2 - \frac{{\bf b}^2}{2}\end{pmatrix}$$



